# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .workflow_runs_create_batch_request_inputs_item import WorkflowRunsCreateBatchRequestInputsItemParams
    from .workflow_runs_create_batch_request_inputs_item_file import WorkflowRunsCreateBatchRequestInputsItemFileParams
    from .workflow_runs_create_batch_response import WorkflowRunsCreateBatchResponseParams
    from .workflow_runs_create_request_file import WorkflowRunsCreateRequestFileParams
    from .workflow_runs_create_request_outputs_item import WorkflowRunsCreateRequestOutputsItemParams
    from .workflow_runs_delete_response import WorkflowRunsDeleteResponseParams
    from .workflow_runs_list_response import WorkflowRunsListResponseParams
_dynamic_imports: typing.Dict[str, str] = {
    "WorkflowRunsCreateBatchRequestInputsItemFileParams": ".workflow_runs_create_batch_request_inputs_item_file",
    "WorkflowRunsCreateBatchRequestInputsItemParams": ".workflow_runs_create_batch_request_inputs_item",
    "WorkflowRunsCreateBatchResponseParams": ".workflow_runs_create_batch_response",
    "WorkflowRunsCreateRequestFileParams": ".workflow_runs_create_request_file",
    "WorkflowRunsCreateRequestOutputsItemParams": ".workflow_runs_create_request_outputs_item",
    "WorkflowRunsDeleteResponseParams": ".workflow_runs_delete_response",
    "WorkflowRunsListResponseParams": ".workflow_runs_list_response",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "WorkflowRunsCreateBatchRequestInputsItemFileParams",
    "WorkflowRunsCreateBatchRequestInputsItemParams",
    "WorkflowRunsCreateBatchResponseParams",
    "WorkflowRunsCreateRequestFileParams",
    "WorkflowRunsCreateRequestOutputsItemParams",
    "WorkflowRunsDeleteResponseParams",
    "WorkflowRunsListResponseParams",
]
