# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..core.serialization import FieldMetadata


class ParseConfigBlockOptionsFiguresParams(typing_extensions.TypedDict):
    """
    Options for figure blocks.
    """

    enabled: typing_extensions.NotRequired[bool]
    """
    Whether to include figures in the output.
    """

    figure_image_clipping_enabled: typing_extensions.NotRequired[
        typing_extensions.Annotated[bool, FieldMetadata(alias="figureImageClippingEnabled")]
    ]
    """
    Whether to clip and extract images from figures.
    """
