# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..core.serialization import FieldMetadata


class FileContentsSheetsItemParams(typing_extensions.TypedDict):
    sheet_name: typing_extensions.Annotated[str, FieldMetadata(alias="sheetName")]
    """
    The name of the sheet.
    """

    raw_text: typing_extensions.NotRequired[typing_extensions.Annotated[str, FieldMetadata(alias="rawText")]]
    """
    The raw text content of the sheet in CSV format.
    """
