# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..core.serialization import FieldMetadata
from .split_run import SplitRunParams


class SplitResultParams(typing_extensions.TypedDict):
    """
    The result of a split step.
    """

    split_run: typing_extensions.Annotated[SplitRunParams, FieldMetadata(alias="splitRun")]
    """
    The split run that was executed.
    """
