# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..core.serialization import FieldMetadata
from ..types.created_at import CreatedAt
from ..types.updated_at import UpdatedAt
from .evaluation_set_entity import EvaluationSetEntityParams


class EvaluationSetParams(typing_extensions.TypedDict):
    object: typing.Literal["evaluation_set"]
    """
    The type of object. In this case, it will always be `"evaluation_set"`.
    """

    id: str
    """
    The ID of the evaluation set.
    
    Example: `"ev_2LcgeY_mp2T5yPaEuq5Lw"`
    """

    name: str
    """
    The name of the evaluation set.
    
    Example: `"Invoice Processing Test Set"`
    """

    description: str
    """
    A description of the evaluation set.
    
    Example: `"Q4 2023 vendor invoices for accuracy testing"`
    """

    entity: EvaluationSetEntityParams
    """
    The extractor, classifier, or splitter associated with this evaluation set.
    """

    created_at: typing_extensions.Annotated[CreatedAt, FieldMetadata(alias="createdAt")]
    updated_at: typing_extensions.Annotated[UpdatedAt, FieldMetadata(alias="updatedAt")]
