# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions


class LegacyProvidedJsonOutputParams(typing_extensions.TypedDict):
    """
    The output from a JSON Schema processor
    """

    value: typing.Dict[str, typing.Any]
