# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..core.serialization import FieldMetadata
from .parse_config_block_options_text_agentic import ParseConfigBlockOptionsTextAgenticParams


class ParseConfigBlockOptionsTextParams(typing_extensions.TypedDict):
    """
    Options for text blocks.
    """

    signature_detection_enabled: typing_extensions.NotRequired[
        typing_extensions.Annotated[bool, FieldMetadata(alias="signatureDetectionEnabled")]
    ]
    """
    Whether an additional vision model will be utilized for advanced signature detection. Recommended for most use cases, but should be disabled if signature detection is not necessary and latency is a concern.
    """

    agentic: typing_extensions.NotRequired[ParseConfigBlockOptionsTextAgenticParams]
    """
    Options for agentic text processing using VLM-based review and correction.
    """
