# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel
from .split_run import SplitRun


class SplitResult(UncheckedBaseModel):
    """
    The result of a split step.
    """

    split_run: typing_extensions.Annotated[SplitRun, FieldMetadata(alias="splitRun")] = pydantic.Field(alias="splitRun")
    """
    The split run that was executed.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
