# This file was auto-generated by Fern from our API Definition.

import typing

from ..core import enum

T_Result = typing.TypeVar("T_Result")


class WebhookSubscriptionResourceType(enum.StrEnum):
    """
    The type of resource the webhook subscription is for.
    """

    EXTRACTOR = "extractor"
    CLASSIFIER = "classifier"
    SPLITTER = "splitter"
    WORKFLOW = "workflow"
    _UNKNOWN = "__WEBHOOKSUBSCRIPTIONRESOURCETYPE_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "WebhookSubscriptionResourceType":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        extractor: typing.Callable[[], T_Result],
        classifier: typing.Callable[[], T_Result],
        splitter: typing.Callable[[], T_Result],
        workflow: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is WebhookSubscriptionResourceType.EXTRACTOR:
            return extractor()
        if self is WebhookSubscriptionResourceType.CLASSIFIER:
            return classifier()
        if self is WebhookSubscriptionResourceType.SPLITTER:
            return splitter()
        if self is WebhookSubscriptionResourceType.WORKFLOW:
            return workflow()
        return _unknown_member(self._value_)
