# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ...core.serialization import FieldMetadata
from ...requests.legacy_processor_version import LegacyProcessorVersionParams


class ProcessorVersionCreateResponseParams(typing_extensions.TypedDict):
    success: bool
    processor_version: typing_extensions.Annotated[
        LegacyProcessorVersionParams, FieldMetadata(alias="processorVersion")
    ]
