# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..core.serialization import FieldMetadata
from .split_run import SplitRunParams


class SplitRunFailedWebhookEventParams(typing_extensions.TypedDict):
    event_id: typing_extensions.Annotated[str, FieldMetadata(alias="eventId")]
    """
    Unique identifier for the event
    """

    payload: SplitRunParams
