# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from .insight import InsightParams


class ClassifyOutputParams(typing_extensions.TypedDict):
    id: str
    """
    The unique identifier for this classification
    """

    type: str
    """
    The type of classification
    """

    confidence: float
    """
    A value between 0 and 1 indicating the model's confidence in the classification, where 1 represents maximum confidence
    """

    insights: typing.Sequence[InsightParams]
    """
    Additional insights about the classification decision
    """
