# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions


class InsightParams(typing_extensions.TypedDict):
    type: typing.Literal["reasoning"]
    """
    The type of insight. Will always be `"reasoning"` for now.
    """

    content: str
    """
    The content of the reasoning insight.
    """
