# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel


class FileContentsSectionsItem(UncheckedBaseModel):
    start_page_number: typing_extensions.Annotated[int, FieldMetadata(alias="startPageNumber")] = pydantic.Field(
        alias="startPageNumber"
    )
    """
    The starting page number of this section.
    """

    end_page_number: typing_extensions.Annotated[int, FieldMetadata(alias="endPageNumber")] = pydantic.Field(
        alias="endPageNumber"
    )
    """
    The ending page number of this section.
    """

    markdown: str = pydantic.Field()
    """
    The markdown content of this section.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
