# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class ParseConfigAdvancedOptionsReturnOcrParams(typing_extensions.TypedDict):
    """
    Options for returning raw OCR data in the response.
    """

    words: typing_extensions.NotRequired[bool]
    """
    Whether to include word-level OCR data in the response, including word bounding boxes and confidence scores. This meaningfully impacts the response size, consider using the signed url return format.
    """
