# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class ClassificationParams(typing_extensions.TypedDict):
    id: str
    """
    Unique identifier for the classification. We recommend lowercase, underscore-separated format.
    """

    type: str
    """
    Type identifier for the classification.
    """

    description: str
    """
    A detailed description of the classification.
    """
