# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..core.serialization import FieldMetadata


class ParseConfigBlockOptionsTextAgenticParams(typing_extensions.TypedDict):
    """
    Options for agentic text processing using VLM-based review and correction.
    """

    enabled: typing_extensions.NotRequired[bool]
    """
    Whether to enable agentic text processing for OCR corrections.
    """

    custom_instructions: typing_extensions.NotRequired[
        typing_extensions.Annotated[str, FieldMetadata(alias="customInstructions")]
    ]
    """
    Custom instructions to guide the agentic text processing.
    """
