# This file was auto-generated by Fern from our API Definition.

import typing

from .classify_step_run import ClassifyStepRunParams
from .conditional_extract_step_run import ConditionalExtractStepRunParams
from .external_data_validation_step_run import ExternalDataValidationStepRunParams
from .extract_step_run import ExtractStepRunParams
from .merge_extract_step_run import MergeExtractStepRunParams
from .parse_step_run import ParseStepRunParams
from .rule_validation_step_run import RuleValidationStepRunParams
from .split_step_run import SplitStepRunParams

StepRunParams = typing.Union[
    ParseStepRunParams,
    ExtractStepRunParams,
    ClassifyStepRunParams,
    SplitStepRunParams,
    MergeExtractStepRunParams,
    ConditionalExtractStepRunParams,
    RuleValidationStepRunParams,
    ExternalDataValidationStepRunParams,
]
