# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ...types.run_metadata import RunMetadata
from ...types.run_secrets import RunSecrets
from .workflow_runs_create_batch_request_inputs_item_file import WorkflowRunsCreateBatchRequestInputsItemFileParams


class WorkflowRunsCreateBatchRequestInputsItemParams(typing_extensions.TypedDict):
    file: WorkflowRunsCreateBatchRequestInputsItemFileParams
    """
    The file to be processed. Files can be provided as a URL, an Extend file ID, or raw text.
    """

    metadata: typing_extensions.NotRequired[RunMetadata]
    secrets: typing_extensions.NotRequired[RunSecrets]
