# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..core.serialization import FieldMetadata


class ProvidedSplitOutputSplitsItemParams(typing_extensions.TypedDict):
    classification_id: typing_extensions.Annotated[str, FieldMetadata(alias="classificationId")]
    """
    ID of the classification type (defined in the splitter config)
    """

    type: str
    """
    The type of the split document (defined in the splitter config), corresponds to the classificationId
    """

    start_page: typing_extensions.Annotated[int, FieldMetadata(alias="startPage")]
    """
    The start page of the split document
    """

    end_page: typing_extensions.Annotated[int, FieldMetadata(alias="endPage")]
    """
    The end page of the split document
    """
