# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions


class WorkflowStepBaseParams(typing_extensions.TypedDict):
    """
    Base properties shared by all workflow step types.
    """

    object: typing.Literal["workflow_step"]
    """
    The type of object. In this case, it will always be `"workflow_step"`.
    """

    id: str
    """
    The ID of the workflow step.
    
    Example: `"step_xKm9pNv3qWsY_jL2tR5Dh"`
    """

    name: str
    """
    The name of the workflow step.
    
    Example: `"Validate Invoice Total"`
    """
