# This file was auto-generated by Fern from our API Definition.

import typing

from .extract_output_metadata_value import ExtractOutputMetadataValue

ExtractOutputMetadata = typing.Dict[str, ExtractOutputMetadataValue]
