# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from .block_metadata_page import BlockMetadataPageParams


class BlockMetadataParams(typing_extensions.TypedDict):
    """
    Metadata about the block.
    """

    page: typing_extensions.NotRequired[BlockMetadataPageParams]
    """
    Information about the page this block appears on.
    """
