# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2
from ...core.serialization import FieldMetadata
from ...core.unchecked_base_model import UncheckedBaseModel
from ...types.processor_version_string import ProcessorVersionString
from ...types.split_override_config import SplitOverrideConfig


class SplitRunsCreateRequestSplitter(UncheckedBaseModel):
    """
    Reference to an existing splitter. One of `splitter` or `config` must be provided.
    """

    id: str = pydantic.Field()
    """
    The ID of the splitter to use.
    """

    version: typing.Optional[ProcessorVersionString] = None
    override_config: typing_extensions.Annotated[
        typing.Optional[SplitOverrideConfig], FieldMetadata(alias="overrideConfig")
    ] = pydantic.Field(alias="overrideConfig", default=None)
    """
    Optional partial configuration override. Only the fields you provide will override the splitter's saved configuration. For example, you can pass only `splitRules` without providing `splitClassifications`.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
