# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..core.serialization import FieldMetadata
from ..types.classify_advanced_options_context import ClassifyAdvancedOptionsContext
from .page_ranges import PageRangesParams


class ClassifyAdvancedOptionsParams(typing_extensions.TypedDict):
    context: typing_extensions.NotRequired[ClassifyAdvancedOptionsContext]
    """
    The context to use for classification.
    """

    advanced_multimodal_enabled: typing_extensions.NotRequired[
        typing_extensions.Annotated[bool, FieldMetadata(alias="advancedMultimodalEnabled")]
    ]
    """
    Enable advanced multimodal processing for better handling of visual elements during classification.
    """

    page_ranges: typing_extensions.NotRequired[
        typing_extensions.Annotated[PageRangesParams, FieldMetadata(alias="pageRanges")]
    ]
