# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .types import (
        ProcessorRunCancelResponse,
        ProcessorRunCreateRequestConfig,
        ProcessorRunCreateRequestConfig_Classify,
        ProcessorRunCreateRequestConfig_Extract,
        ProcessorRunCreateRequestConfig_Splitter,
        ProcessorRunCreateResponse,
        ProcessorRunDeleteResponse,
        ProcessorRunGetResponse,
        ProcessorRunListRequestSource,
        ProcessorRunListResponse,
    )
    from .requests import (
        ProcessorRunCancelResponseParams,
        ProcessorRunCreateRequestConfigParams,
        ProcessorRunCreateRequestConfig_ClassifyParams,
        ProcessorRunCreateRequestConfig_ExtractParams,
        ProcessorRunCreateRequestConfig_SplitterParams,
        ProcessorRunCreateResponseParams,
        ProcessorRunDeleteResponseParams,
        ProcessorRunGetResponseParams,
        ProcessorRunListResponseParams,
    )
_dynamic_imports: typing.Dict[str, str] = {
    "ProcessorRunCancelResponse": ".types",
    "ProcessorRunCancelResponseParams": ".requests",
    "ProcessorRunCreateRequestConfig": ".types",
    "ProcessorRunCreateRequestConfigParams": ".requests",
    "ProcessorRunCreateRequestConfig_Classify": ".types",
    "ProcessorRunCreateRequestConfig_ClassifyParams": ".requests",
    "ProcessorRunCreateRequestConfig_Extract": ".types",
    "ProcessorRunCreateRequestConfig_ExtractParams": ".requests",
    "ProcessorRunCreateRequestConfig_Splitter": ".types",
    "ProcessorRunCreateRequestConfig_SplitterParams": ".requests",
    "ProcessorRunCreateResponse": ".types",
    "ProcessorRunCreateResponseParams": ".requests",
    "ProcessorRunDeleteResponse": ".types",
    "ProcessorRunDeleteResponseParams": ".requests",
    "ProcessorRunGetResponse": ".types",
    "ProcessorRunGetResponseParams": ".requests",
    "ProcessorRunListRequestSource": ".types",
    "ProcessorRunListResponse": ".types",
    "ProcessorRunListResponseParams": ".requests",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "ProcessorRunCancelResponse",
    "ProcessorRunCancelResponseParams",
    "ProcessorRunCreateRequestConfig",
    "ProcessorRunCreateRequestConfigParams",
    "ProcessorRunCreateRequestConfig_Classify",
    "ProcessorRunCreateRequestConfig_ClassifyParams",
    "ProcessorRunCreateRequestConfig_Extract",
    "ProcessorRunCreateRequestConfig_ExtractParams",
    "ProcessorRunCreateRequestConfig_Splitter",
    "ProcessorRunCreateRequestConfig_SplitterParams",
    "ProcessorRunCreateResponse",
    "ProcessorRunCreateResponseParams",
    "ProcessorRunDeleteResponse",
    "ProcessorRunDeleteResponseParams",
    "ProcessorRunGetResponse",
    "ProcessorRunGetResponseParams",
    "ProcessorRunListRequestSource",
    "ProcessorRunListResponse",
    "ProcessorRunListResponseParams",
]
