# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, update_forward_refs
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel


class EditRootJson(UncheckedBaseModel):
    """
    JSON Schema definition for editing PDF documents. The schema defines the structure and placement of fields to edit.
    """

    type: typing.Literal["object"] = pydantic.Field(default="object")
    """
    Must be "object" for the root schema
    """

    properties: typing.Dict[str, "EditJson"] = pydantic.Field()
    """
    Map of field names to their schema definitions
    """

    required: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    List of required field names
    """

    additional_properties: typing_extensions.Annotated[
        typing.Optional[bool], FieldMetadata(alias="additionalProperties")
    ] = pydantic.Field(alias="additionalProperties", default=None)
    """
    Whether additional properties are allowed
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


from .edit_json import EditJson  # noqa: E402, I001
from .edit_object_json import EditObjectJson  # noqa: E402, I001

update_forward_refs(EditRootJson, EditJson=EditJson, EditObjectJson=EditObjectJson)
