# This file was auto-generated by Fern from our API Definition.

import typing

from .legacy_classifier_output import LegacyClassifierOutput
from .legacy_extraction_output import LegacyExtractionOutput
from .legacy_splitter_output import LegacySplitterOutput

LegacyProcessorOutput = typing.Union[LegacyExtractionOutput, LegacyClassifierOutput, LegacySplitterOutput]
