# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..core.serialization import FieldMetadata


class TableCellDetailsParams(typing_extensions.TypedDict):
    """
    Details for table cell blocks
    """

    type: typing.Literal["table_cell_details"]
    """
    Indicates this is a table cell details object
    """

    row_index: typing_extensions.Annotated[int, FieldMetadata(alias="rowIndex")]
    column_index: typing_extensions.Annotated[int, FieldMetadata(alias="columnIndex")]
