# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..core.serialization import FieldMetadata
from ..types.created_at import CreatedAt
from ..types.updated_at import UpdatedAt
from .classifier_version import ClassifierVersionParams


class ClassifierParams(typing_extensions.TypedDict):
    object: typing.Literal["classifier"]
    """
    The type of object. Will always be `"classifier"`.
    """

    id: str
    """
    The ID of the classifier.
    
    Example: `"cl_Xj8mK2pL9nR4vT7qY5wZ"`
    """

    name: str
    """
    The name of the classifier.
    
    Example: `"Document Type Classifier"`
    """

    created_at: typing_extensions.Annotated[CreatedAt, FieldMetadata(alias="createdAt")]
    updated_at: typing_extensions.Annotated[UpdatedAt, FieldMetadata(alias="updatedAt")]
    draft_version: typing_extensions.Annotated[ClassifierVersionParams, FieldMetadata(alias="draftVersion")]
    """
    The draft version of the classifier. This is the editable version in the Extend dashboard.
    """
