# This file was auto-generated by Fern from our API Definition.

import typing

from ..core import enum

T_Result = typing.TypeVar("T_Result")


class LegacyProcessorType(enum.StrEnum):
    """
    The type of processor:
    * `"EXTRACT"` - Extracts structured data from documents
    * `"CLASSIFY"` - Classifies documents into categories
    * `"SPLITTER"` - Splits documents into multiple parts
    """

    EXTRACT = "EXTRACT"
    CLASSIFY = "CLASSIFY"
    SPLITTER = "SPLITTER"
    _UNKNOWN = "__LEGACYPROCESSORTYPE_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "LegacyProcessorType":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        extract: typing.Callable[[], T_Result],
        classify: typing.Callable[[], T_Result],
        splitter: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is LegacyProcessorType.EXTRACT:
            return extract()
        if self is LegacyProcessorType.CLASSIFY:
            return classify()
        if self is LegacyProcessorType.SPLITTER:
            return splitter()
        return _unknown_member(self._value_)
