# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..core.serialization import FieldMetadata
from ..types.split_base_processor import SplitBaseProcessor
from .classifications import ClassificationsParams
from .parse_config import ParseConfigParams
from .split_advanced_options import SplitAdvancedOptionsParams


class SplitConfigParams(typing_extensions.TypedDict):
    base_processor: typing_extensions.NotRequired[
        typing_extensions.Annotated[SplitBaseProcessor, FieldMetadata(alias="baseProcessor")]
    ]
    base_version: typing_extensions.NotRequired[typing_extensions.Annotated[str, FieldMetadata(alias="baseVersion")]]
    """
    The version of the `"splitting_performance"` or `"splitting_light"` processor to use. If not provided, the latest stable version for the selected `baseProcessor` will be used automatically. See [Splitting Changelog](https://docs.extend.ai/2026-02-09/changelog/splitting/splitting-performance) for more details.
    """

    split_classifications: typing_extensions.Annotated[
        ClassificationsParams, FieldMetadata(alias="splitClassifications")
    ]
    split_rules: typing_extensions.NotRequired[typing_extensions.Annotated[str, FieldMetadata(alias="splitRules")]]
    """
    Custom rules to guide the document splitting process in natural language.
    """

    advanced_options: typing_extensions.NotRequired[
        typing_extensions.Annotated[SplitAdvancedOptionsParams, FieldMetadata(alias="advancedOptions")]
    ]
    """
    Advanced configuration options.
    """

    parse_config: typing_extensions.NotRequired[
        typing_extensions.Annotated[ParseConfigParams, FieldMetadata(alias="parseConfig")]
    ]
    """
    Configuration options for the parsing process.
    """
