# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel


class ParseConfigBlockOptionsTextAgentic(UncheckedBaseModel):
    """
    Options for agentic text processing using VLM-based review and correction.
    """

    enabled: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Whether to enable agentic text processing for OCR corrections.
    """

    custom_instructions: typing_extensions.Annotated[
        typing.Optional[str], FieldMetadata(alias="customInstructions")
    ] = pydantic.Field(alias="customInstructions", default=None)
    """
    Custom instructions to guide the agentic text processing.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
