# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .api_error import ApiError
    from .api_version_enum import ApiVersionEnum
    from .array_strategy import ArrayStrategy
    from .array_strategy_type import ArrayStrategyType
    from .batch_processor_run import BatchProcessorRun
    from .batch_processor_run_metrics import BatchProcessorRunMetrics
    from .batch_processor_run_options import BatchProcessorRunOptions
    from .batch_processor_run_source import BatchProcessorRunSource
    from .batch_processor_run_status import BatchProcessorRunStatus
    from .batch_run import BatchRun
    from .batch_run_entity import (
        BatchRunEntity,
        BatchRunEntity_Classifier,
        BatchRunEntity_Extractor,
        BatchRunEntity_Splitter,
    )
    from .batch_run_entity_version import (
        BatchRunEntityVersion,
        BatchRunEntityVersion_ClassifierVersion,
        BatchRunEntityVersion_ExtractorVersion,
        BatchRunEntityVersion_SplitterVersion,
    )
    from .batch_run_metrics import BatchRunMetrics
    from .batch_run_status import BatchRunStatus
    from .block import Block
    from .block_details import BlockDetails
    from .block_metadata import BlockMetadata
    from .block_metadata_page import BlockMetadataPage
    from .block_polygon_item import BlockPolygonItem
    from .block_type import BlockType
    from .bounding_box import BoundingBox
    from .chunk import Chunk
    from .chunk_metadata import ChunkMetadata
    from .chunk_metadata_page_range import ChunkMetadataPageRange
    from .chunk_type import ChunkType
    from .citation import Citation
    from .citation_page import CitationPage
    from .classification import Classification
    from .classifications import Classifications
    from .classifier import Classifier
    from .classifier_created_webhook_event import ClassifierCreatedWebhookEvent
    from .classifier_deleted_webhook_event import ClassifierDeletedWebhookEvent
    from .classifier_draft_updated_webhook_event import ClassifierDraftUpdatedWebhookEvent
    from .classifier_summary import ClassifierSummary
    from .classifier_updated_webhook_event import ClassifierUpdatedWebhookEvent
    from .classifier_version import ClassifierVersion
    from .classifier_version_published_webhook_event import ClassifierVersionPublishedWebhookEvent
    from .classifier_version_summary import ClassifierVersionSummary
    from .classify_advanced_options import ClassifyAdvancedOptions
    from .classify_advanced_options_context import ClassifyAdvancedOptionsContext
    from .classify_base_processor import ClassifyBaseProcessor
    from .classify_config import ClassifyConfig
    from .classify_output import ClassifyOutput
    from .classify_override_config import ClassifyOverrideConfig
    from .classify_request_classifier import ClassifyRequestClassifier
    from .classify_request_file import ClassifyRequestFile
    from .classify_result import ClassifyResult
    from .classify_run import ClassifyRun
    from .classify_run_failed_webhook_event import ClassifyRunFailedWebhookEvent
    from .classify_run_processed_webhook_event import ClassifyRunProcessedWebhookEvent
    from .classify_run_summary import ClassifyRunSummary
    from .classify_step_run import ClassifyStepRun
    from .classify_step_run_step import ClassifyStepRunStep
    from .conditional_extract_result import ConditionalExtractResult
    from .conditional_extract_step_run import ConditionalExtractStepRun
    from .conditional_extract_step_run_step import ConditionalExtractStepRunStep
    from .created_at import CreatedAt
    from .edit_bounding_box import EditBoundingBox
    from .edit_config import EditConfig
    from .edit_config_advanced_options import EditConfigAdvancedOptions
    from .edit_json import EditJson
    from .edit_json_extend_edit_field_type import EditJsonExtendEditFieldType
    from .edit_object_json import EditObjectJson
    from .edit_request_file import EditRequestFile
    from .edit_root_json import EditRootJson
    from .edit_run import EditRun
    from .edit_run_failed_webhook_event import EditRunFailedWebhookEvent
    from .edit_run_metrics import EditRunMetrics
    from .edit_run_output import EditRunOutput
    from .edit_run_output_edited_file import EditRunOutputEditedFile
    from .edit_run_processed_webhook_event import EditRunProcessedWebhookEvent
    from .edit_run_status import EditRunStatus
    from .edit_text_options import EditTextOptions
    from .empty_block_details import EmptyBlockDetails
    from .enum import Enum
    from .enum_option import EnumOption
    from .evaluation_set import EvaluationSet
    from .evaluation_set_entity import (
        EvaluationSetEntity,
        EvaluationSetEntity_Classifier,
        EvaluationSetEntity_Extractor,
        EvaluationSetEntity_Splitter,
    )
    from .evaluation_set_item import EvaluationSetItem
    from .evaluation_set_item_summary import EvaluationSetItemSummary
    from .evaluation_set_run import EvaluationSetRun
    from .evaluation_set_run_entity import (
        EvaluationSetRunEntity,
        EvaluationSetRunEntity_Classifier,
        EvaluationSetRunEntity_Extractor,
        EvaluationSetRunEntity_Splitter,
    )
    from .evaluation_set_run_entity_version import (
        EvaluationSetRunEntityVersion,
        EvaluationSetRunEntityVersion_ClassifierVersion,
        EvaluationSetRunEntityVersion_ExtractorVersion,
        EvaluationSetRunEntityVersion_SplitterVersion,
    )
    from .evaluation_set_run_metrics import EvaluationSetRunMetrics
    from .evaluation_set_run_options import EvaluationSetRunOptions
    from .excel_sheet_range import ExcelSheetRange
    from .external_data_validation_result import ExternalDataValidationResult
    from .external_data_validation_result_response import ExternalDataValidationResultResponse
    from .external_data_validation_step_run import ExternalDataValidationStepRun
    from .external_data_validation_step_run_step import ExternalDataValidationStepRunStep
    from .extract_advanced_options import ExtractAdvancedOptions
    from .extract_advanced_options_array_citation_strategy import ExtractAdvancedOptionsArrayCitationStrategy
    from .extract_advanced_options_excel_sheet_selection_strategy import (
        ExtractAdvancedOptionsExcelSheetSelectionStrategy,
    )
    from .extract_advanced_options_review_agent import ExtractAdvancedOptionsReviewAgent
    from .extract_base_processor import ExtractBaseProcessor
    from .extract_chunking_options import ExtractChunkingOptions
    from .extract_chunking_options_chunk_selection_strategy import ExtractChunkingOptionsChunkSelectionStrategy
    from .extract_chunking_options_chunking_strategy import ExtractChunkingOptionsChunkingStrategy
    from .extract_config import ExtractConfig
    from .extract_config_json import ExtractConfigJson
    from .extract_config_legacy import ExtractConfigLegacy
    from .extract_config_legacy_base_processor import ExtractConfigLegacyBaseProcessor
    from .extract_output import ExtractOutput
    from .extract_output_edits import ExtractOutputEdits
    from .extract_output_json import ExtractOutputJson
    from .extract_output_legacy import ExtractOutputLegacy
    from .extract_output_metadata import ExtractOutputMetadata
    from .extract_output_metadata_value import ExtractOutputMetadataValue
    from .extract_override_config_json import ExtractOverrideConfigJson
    from .extract_request_extractor import ExtractRequestExtractor
    from .extract_request_file import ExtractRequestFile
    from .extract_result import ExtractResult
    from .extract_run import ExtractRun
    from .extract_run_failed_webhook_event import ExtractRunFailedWebhookEvent
    from .extract_run_processed_webhook_event import ExtractRunProcessedWebhookEvent
    from .extract_run_summary import ExtractRunSummary
    from .extract_step_run import ExtractStepRun
    from .extract_step_run_step import ExtractStepRunStep
    from .extraction_field import ExtractionField
    from .extraction_field_result import ExtractionFieldResult
    from .extraction_field_result_reference import ExtractionFieldResultReference
    from .extraction_field_result_reference_bounding_boxes_item import ExtractionFieldResultReferenceBoundingBoxesItem
    from .extraction_field_result_type import ExtractionFieldResultType
    from .extraction_field_type import ExtractionFieldType
    from .extractor import Extractor
    from .extractor_created_webhook_event import ExtractorCreatedWebhookEvent
    from .extractor_deleted_webhook_event import ExtractorDeletedWebhookEvent
    from .extractor_draft_updated_webhook_event import ExtractorDraftUpdatedWebhookEvent
    from .extractor_summary import ExtractorSummary
    from .extractor_updated_webhook_event import ExtractorUpdatedWebhookEvent
    from .extractor_version import ExtractorVersion
    from .extractor_version_published_webhook_event import ExtractorVersionPublishedWebhookEvent
    from .extractor_version_summary import ExtractorVersionSummary
    from .figure_details import FigureDetails
    from .figure_details_figure_type import FigureDetailsFigureType
    from .file import File
    from .file_contents import FileContents
    from .file_contents_pages_item import FileContentsPagesItem
    from .file_contents_sections_item import FileContentsSectionsItem
    from .file_contents_sheets_item import FileContentsSheetsItem
    from .file_from_id import FileFromId
    from .file_from_text import FileFromText
    from .file_from_url import FileFromUrl
    from .file_metadata import FileMetadata
    from .file_summary import FileSummary
    from .file_type import FileType
    from .insight import Insight
    from .json_object import JsonObject
    from .legacy_batch_processor_run import LegacyBatchProcessorRun
    from .legacy_batch_processor_run_metrics import LegacyBatchProcessorRunMetrics
    from .legacy_batch_processor_run_options import LegacyBatchProcessorRunOptions
    from .legacy_batch_processor_run_source import LegacyBatchProcessorRunSource
    from .legacy_batch_processor_run_status import LegacyBatchProcessorRunStatus
    from .legacy_classification import LegacyClassification
    from .legacy_classification_advanced_options import LegacyClassificationAdvancedOptions
    from .legacy_classification_advanced_options_context import LegacyClassificationAdvancedOptionsContext
    from .legacy_classification_config import LegacyClassificationConfig
    from .legacy_classification_config_base_processor import LegacyClassificationConfigBaseProcessor
    from .legacy_classifier_output import LegacyClassifierOutput
    from .legacy_document_processor_run_credits import LegacyDocumentProcessorRunCredits
    from .legacy_error import LegacyError
    from .legacy_extend_error import LegacyExtendError
    from .legacy_extract_chunking_options import LegacyExtractChunkingOptions
    from .legacy_extract_chunking_options_chunk_selection_strategy import (
        LegacyExtractChunkingOptionsChunkSelectionStrategy,
    )
    from .legacy_extract_chunking_options_chunking_strategy import LegacyExtractChunkingOptionsChunkingStrategy
    from .legacy_extraction_advanced_options import LegacyExtractionAdvancedOptions
    from .legacy_extraction_advanced_options_array_citation_strategy import (
        LegacyExtractionAdvancedOptionsArrayCitationStrategy,
    )
    from .legacy_extraction_advanced_options_excel_sheet_selection_strategy import (
        LegacyExtractionAdvancedOptionsExcelSheetSelectionStrategy,
    )
    from .legacy_extraction_advanced_options_review_agent import LegacyExtractionAdvancedOptionsReviewAgent
    from .legacy_extraction_config import LegacyExtractionConfig
    from .legacy_extraction_config_base_processor import LegacyExtractionConfigBaseProcessor
    from .legacy_extraction_field import LegacyExtractionField
    from .legacy_extraction_field_result import LegacyExtractionFieldResult
    from .legacy_extraction_field_result_type import LegacyExtractionFieldResultType
    from .legacy_extraction_field_type import LegacyExtractionFieldType
    from .legacy_extraction_output import LegacyExtractionOutput
    from .legacy_extraction_output_edits import LegacyExtractionOutputEdits
    from .legacy_fields_array_output import LegacyFieldsArrayOutput
    from .legacy_json_object import LegacyJsonObject
    from .legacy_json_output import LegacyJsonOutput
    from .legacy_json_output_metadata_value import LegacyJsonOutputMetadataValue
    from .legacy_json_output_metadata_value_citations_item import LegacyJsonOutputMetadataValueCitationsItem
    from .legacy_json_output_metadata_value_citations_item_polygon_item import (
        LegacyJsonOutputMetadataValueCitationsItemPolygonItem,
    )
    from .legacy_list_processors_processor import LegacyListProcessorsProcessor
    from .legacy_list_processors_processor_version import LegacyListProcessorsProcessorVersion
    from .legacy_list_processors_response import LegacyListProcessorsResponse
    from .legacy_max_page_size import LegacyMaxPageSize
    from .legacy_next_page_token import LegacyNextPageToken
    from .legacy_processor import LegacyProcessor
    from .legacy_processor_id import LegacyProcessorId
    from .legacy_processor_output import LegacyProcessorOutput
    from .legacy_processor_run import LegacyProcessorRun
    from .legacy_processor_run_config import (
        LegacyProcessorRunConfig,
        LegacyProcessorRunConfig_Classify,
        LegacyProcessorRunConfig_Extract,
        LegacyProcessorRunConfig_Splitter,
    )
    from .legacy_processor_run_file_input import LegacyProcessorRunFileInput
    from .legacy_processor_run_merged_processors_item import LegacyProcessorRunMergedProcessorsItem
    from .legacy_processor_run_summary import LegacyProcessorRunSummary
    from .legacy_processor_run_summary_type import LegacyProcessorRunSummaryType
    from .legacy_processor_run_type import LegacyProcessorRunType
    from .legacy_processor_status import LegacyProcessorStatus
    from .legacy_processor_type import LegacyProcessorType
    from .legacy_processor_version import LegacyProcessorVersion
    from .legacy_processor_version_config import (
        LegacyProcessorVersionConfig,
        LegacyProcessorVersionConfig_Classify,
        LegacyProcessorVersionConfig_Extract,
        LegacyProcessorVersionConfig_Splitter,
    )
    from .legacy_provided_classifier_output import LegacyProvidedClassifierOutput
    from .legacy_provided_extraction_field_result import LegacyProvidedExtractionFieldResult
    from .legacy_provided_extraction_field_result_type import LegacyProvidedExtractionFieldResultType
    from .legacy_provided_extraction_output import LegacyProvidedExtractionOutput
    from .legacy_provided_fields_array_output import LegacyProvidedFieldsArrayOutput
    from .legacy_provided_json_output import LegacyProvidedJsonOutput
    from .legacy_provided_processor_output import LegacyProvidedProcessorOutput
    from .legacy_provided_splitter_output import LegacyProvidedSplitterOutput
    from .legacy_provided_splitter_output_splits_item import LegacyProvidedSplitterOutputSplitsItem
    from .legacy_sort_by_enum import LegacySortByEnum
    from .legacy_sort_dir_enum import LegacySortDirEnum
    from .legacy_splitter_advanced_options import LegacySplitterAdvancedOptions
    from .legacy_splitter_advanced_options_split_method import LegacySplitterAdvancedOptionsSplitMethod
    from .legacy_splitter_config import LegacySplitterConfig
    from .legacy_splitter_config_base_processor import LegacySplitterConfigBaseProcessor
    from .legacy_splitter_output import LegacySplitterOutput
    from .legacy_splitter_output_splits_item import LegacySplitterOutputSplitsItem
    from .max_page_size import MaxPageSize
    from .merge_extract_result import MergeExtractResult
    from .merge_extract_result_merged_extractors_item import MergeExtractResultMergedExtractorsItem
    from .merge_extract_step_run import MergeExtractStepRun
    from .merge_extract_step_run_step import MergeExtractStepRunStep
    from .next_page_token import NextPageToken
    from .page_ranges import PageRanges
    from .page_ranges_item import PageRangesItem
    from .parent_split import ParentSplit
    from .parse_config import ParseConfig
    from .parse_config_advanced_options import ParseConfigAdvancedOptions
    from .parse_config_advanced_options_excel_parsing_mode import ParseConfigAdvancedOptionsExcelParsingMode
    from .parse_config_advanced_options_return_ocr import ParseConfigAdvancedOptionsReturnOcr
    from .parse_config_block_options import ParseConfigBlockOptions
    from .parse_config_block_options_figures import ParseConfigBlockOptionsFigures
    from .parse_config_block_options_tables import ParseConfigBlockOptionsTables
    from .parse_config_block_options_tables_agentic import ParseConfigBlockOptionsTablesAgentic
    from .parse_config_block_options_tables_target_format import ParseConfigBlockOptionsTablesTargetFormat
    from .parse_config_block_options_text import ParseConfigBlockOptionsText
    from .parse_config_block_options_text_agentic import ParseConfigBlockOptionsTextAgentic
    from .parse_config_chunking_strategy import ParseConfigChunkingStrategy
    from .parse_config_chunking_strategy_options import ParseConfigChunkingStrategyOptions
    from .parse_config_chunking_strategy_type import ParseConfigChunkingStrategyType
    from .parse_config_engine import ParseConfigEngine
    from .parse_config_target import ParseConfigTarget
    from .parse_request_file import ParseRequestFile
    from .parse_request_response_type import ParseRequestResponseType
    from .parse_result import ParseResult
    from .parse_run import ParseRun
    from .parse_run_failed_webhook_event import ParseRunFailedWebhookEvent
    from .parse_run_metrics import ParseRunMetrics
    from .parse_run_output import ParseRunOutput
    from .parse_run_output_ocr import ParseRunOutputOcr
    from .parse_run_output_ocr_words_item import ParseRunOutputOcrWordsItem
    from .parse_run_processed_webhook_event import ParseRunProcessedWebhookEvent
    from .parse_run_status import ParseRunStatus
    from .parse_run_status_enum import ParseRunStatusEnum
    from .parse_run_status_status import ParseRunStatusStatus
    from .parse_step_run import ParseStepRun
    from .parse_step_run_step import ParseStepRunStep
    from .polygon import Polygon
    from .processor_run_status import ProcessorRunStatus
    from .processor_version_string import ProcessorVersionString
    from .provided_classify_output import ProvidedClassifyOutput
    from .provided_extract_output import ProvidedExtractOutput
    from .provided_processor_output import ProvidedProcessorOutput
    from .provided_split_output import ProvidedSplitOutput
    from .provided_split_output_splits_item import ProvidedSplitOutputSplitsItem
    from .release_type import ReleaseType
    from .rule_validation_result import RuleValidationResult
    from .rule_validation_result_rules_item import RuleValidationResultRulesItem
    from .rule_validation_result_rules_item_failure_reason import RuleValidationResultRulesItemFailureReason
    from .rule_validation_step_run import RuleValidationStepRun
    from .rule_validation_step_run_step import RuleValidationStepRunStep
    from .run_metadata import RunMetadata
    from .run_priority import RunPriority
    from .run_secrets import RunSecrets
    from .run_source import RunSource
    from .run_source_id import RunSourceId
    from .run_usage import RunUsage
    from .sort_by import SortBy
    from .sort_dir import SortDir
    from .split_advanced_options import SplitAdvancedOptions
    from .split_advanced_options_split_method import SplitAdvancedOptionsSplitMethod
    from .split_base_processor import SplitBaseProcessor
    from .split_config import SplitConfig
    from .split_output import SplitOutput
    from .split_output_splits_item import SplitOutputSplitsItem
    from .split_override_config import SplitOverrideConfig
    from .split_request_file import SplitRequestFile
    from .split_request_splitter import SplitRequestSplitter
    from .split_result import SplitResult
    from .split_run import SplitRun
    from .split_run_failed_webhook_event import SplitRunFailedWebhookEvent
    from .split_run_processed_webhook_event import SplitRunProcessedWebhookEvent
    from .split_run_summary import SplitRunSummary
    from .split_step_run import SplitStepRun
    from .split_step_run_step import SplitStepRunStep
    from .splitter import Splitter
    from .splitter_created_webhook_event import SplitterCreatedWebhookEvent
    from .splitter_deleted_webhook_event import SplitterDeletedWebhookEvent
    from .splitter_draft_updated_webhook_event import SplitterDraftUpdatedWebhookEvent
    from .splitter_summary import SplitterSummary
    from .splitter_updated_webhook_event import SplitterUpdatedWebhookEvent
    from .splitter_version import SplitterVersion
    from .splitter_version_published_webhook_event import SplitterVersionPublishedWebhookEvent
    from .splitter_version_summary import SplitterVersionSummary
    from .step_run import StepRun
    from .step_run_base import StepRunBase
    from .step_run_base_status import StepRunBaseStatus
    from .table_cell_details import TableCellDetails
    from .table_details import TableDetails
    from .too_many_requests_error_body import TooManyRequestsErrorBody
    from .updated_at import UpdatedAt
    from .version_description import VersionDescription
    from .webhook_advanced_options import WebhookAdvancedOptions
    from .webhook_endpoint import WebhookEndpoint
    from .webhook_endpoint_create import WebhookEndpointCreate
    from .webhook_endpoint_event_type import WebhookEndpointEventType
    from .webhook_endpoint_status import WebhookEndpointStatus
    from .webhook_event import (
        WebhookEvent,
        WebhookEvent_ClassifierCreated,
        WebhookEvent_ClassifierDeleted,
        WebhookEvent_ClassifierDraftUpdated,
        WebhookEvent_ClassifierUpdated,
        WebhookEvent_ClassifierVersionPublished,
        WebhookEvent_ClassifyRunFailed,
        WebhookEvent_ClassifyRunProcessed,
        WebhookEvent_EditRunFailed,
        WebhookEvent_EditRunProcessed,
        WebhookEvent_ExtractRunFailed,
        WebhookEvent_ExtractRunProcessed,
        WebhookEvent_ExtractorCreated,
        WebhookEvent_ExtractorDeleted,
        WebhookEvent_ExtractorDraftUpdated,
        WebhookEvent_ExtractorUpdated,
        WebhookEvent_ExtractorVersionPublished,
        WebhookEvent_ParseRunFailed,
        WebhookEvent_ParseRunProcessed,
        WebhookEvent_SplitRunFailed,
        WebhookEvent_SplitRunProcessed,
        WebhookEvent_SplitterCreated,
        WebhookEvent_SplitterDeleted,
        WebhookEvent_SplitterDraftUpdated,
        WebhookEvent_SplitterUpdated,
        WebhookEvent_SplitterVersionPublished,
        WebhookEvent_WorkflowCreated,
        WebhookEvent_WorkflowDeleted,
        WebhookEvent_WorkflowDeployed,
        WebhookEvent_WorkflowRunCancelled,
        WebhookEvent_WorkflowRunCompleted,
        WebhookEvent_WorkflowRunFailed,
        WebhookEvent_WorkflowRunNeedsReview,
        WebhookEvent_WorkflowRunRejected,
        WebhookEvent_WorkflowRunStepRunProcessed,
    )
    from .webhook_payload_format import WebhookPayloadFormat
    from .webhook_payload_options import WebhookPayloadOptions
    from .webhook_subscription import WebhookSubscription
    from .webhook_subscription_event_type import WebhookSubscriptionEventType
    from .webhook_subscription_resource_type import WebhookSubscriptionResourceType
    from .workflow import Workflow
    from .workflow_created_webhook_event import WorkflowCreatedWebhookEvent
    from .workflow_deleted_webhook_event import WorkflowDeletedWebhookEvent
    from .workflow_deployed_webhook_event import WorkflowDeployedWebhookEvent
    from .workflow_reference import WorkflowReference
    from .workflow_run import WorkflowRun
    from .workflow_run_cancelled_webhook_event import WorkflowRunCancelledWebhookEvent
    from .workflow_run_completed_webhook_event import WorkflowRunCompletedWebhookEvent
    from .workflow_run_failed_webhook_event import WorkflowRunFailedWebhookEvent
    from .workflow_run_needs_review_webhook_event import WorkflowRunNeedsReviewWebhookEvent
    from .workflow_run_rejected_webhook_event import WorkflowRunRejectedWebhookEvent
    from .workflow_run_status import WorkflowRunStatus
    from .workflow_run_step_run_processed_webhook_event import WorkflowRunStepRunProcessedWebhookEvent
    from .workflow_run_summary import WorkflowRunSummary
    from .workflow_step_base import WorkflowStepBase
    from .workflow_summary import WorkflowSummary
    from .workflow_version import WorkflowVersion
    from .workflow_version_summary import WorkflowVersionSummary
_dynamic_imports: typing.Dict[str, str] = {
    "ApiError": ".api_error",
    "ApiVersionEnum": ".api_version_enum",
    "ArrayStrategy": ".array_strategy",
    "ArrayStrategyType": ".array_strategy_type",
    "BatchProcessorRun": ".batch_processor_run",
    "BatchProcessorRunMetrics": ".batch_processor_run_metrics",
    "BatchProcessorRunOptions": ".batch_processor_run_options",
    "BatchProcessorRunSource": ".batch_processor_run_source",
    "BatchProcessorRunStatus": ".batch_processor_run_status",
    "BatchRun": ".batch_run",
    "BatchRunEntity": ".batch_run_entity",
    "BatchRunEntityVersion": ".batch_run_entity_version",
    "BatchRunEntityVersion_ClassifierVersion": ".batch_run_entity_version",
    "BatchRunEntityVersion_ExtractorVersion": ".batch_run_entity_version",
    "BatchRunEntityVersion_SplitterVersion": ".batch_run_entity_version",
    "BatchRunEntity_Classifier": ".batch_run_entity",
    "BatchRunEntity_Extractor": ".batch_run_entity",
    "BatchRunEntity_Splitter": ".batch_run_entity",
    "BatchRunMetrics": ".batch_run_metrics",
    "BatchRunStatus": ".batch_run_status",
    "Block": ".block",
    "BlockDetails": ".block_details",
    "BlockMetadata": ".block_metadata",
    "BlockMetadataPage": ".block_metadata_page",
    "BlockPolygonItem": ".block_polygon_item",
    "BlockType": ".block_type",
    "BoundingBox": ".bounding_box",
    "Chunk": ".chunk",
    "ChunkMetadata": ".chunk_metadata",
    "ChunkMetadataPageRange": ".chunk_metadata_page_range",
    "ChunkType": ".chunk_type",
    "Citation": ".citation",
    "CitationPage": ".citation_page",
    "Classification": ".classification",
    "Classifications": ".classifications",
    "Classifier": ".classifier",
    "ClassifierCreatedWebhookEvent": ".classifier_created_webhook_event",
    "ClassifierDeletedWebhookEvent": ".classifier_deleted_webhook_event",
    "ClassifierDraftUpdatedWebhookEvent": ".classifier_draft_updated_webhook_event",
    "ClassifierSummary": ".classifier_summary",
    "ClassifierUpdatedWebhookEvent": ".classifier_updated_webhook_event",
    "ClassifierVersion": ".classifier_version",
    "ClassifierVersionPublishedWebhookEvent": ".classifier_version_published_webhook_event",
    "ClassifierVersionSummary": ".classifier_version_summary",
    "ClassifyAdvancedOptions": ".classify_advanced_options",
    "ClassifyAdvancedOptionsContext": ".classify_advanced_options_context",
    "ClassifyBaseProcessor": ".classify_base_processor",
    "ClassifyConfig": ".classify_config",
    "ClassifyOutput": ".classify_output",
    "ClassifyOverrideConfig": ".classify_override_config",
    "ClassifyRequestClassifier": ".classify_request_classifier",
    "ClassifyRequestFile": ".classify_request_file",
    "ClassifyResult": ".classify_result",
    "ClassifyRun": ".classify_run",
    "ClassifyRunFailedWebhookEvent": ".classify_run_failed_webhook_event",
    "ClassifyRunProcessedWebhookEvent": ".classify_run_processed_webhook_event",
    "ClassifyRunSummary": ".classify_run_summary",
    "ClassifyStepRun": ".classify_step_run",
    "ClassifyStepRunStep": ".classify_step_run_step",
    "ConditionalExtractResult": ".conditional_extract_result",
    "ConditionalExtractStepRun": ".conditional_extract_step_run",
    "ConditionalExtractStepRunStep": ".conditional_extract_step_run_step",
    "CreatedAt": ".created_at",
    "EditBoundingBox": ".edit_bounding_box",
    "EditConfig": ".edit_config",
    "EditConfigAdvancedOptions": ".edit_config_advanced_options",
    "EditJson": ".edit_json",
    "EditJsonExtendEditFieldType": ".edit_json_extend_edit_field_type",
    "EditObjectJson": ".edit_object_json",
    "EditRequestFile": ".edit_request_file",
    "EditRootJson": ".edit_root_json",
    "EditRun": ".edit_run",
    "EditRunFailedWebhookEvent": ".edit_run_failed_webhook_event",
    "EditRunMetrics": ".edit_run_metrics",
    "EditRunOutput": ".edit_run_output",
    "EditRunOutputEditedFile": ".edit_run_output_edited_file",
    "EditRunProcessedWebhookEvent": ".edit_run_processed_webhook_event",
    "EditRunStatus": ".edit_run_status",
    "EditTextOptions": ".edit_text_options",
    "EmptyBlockDetails": ".empty_block_details",
    "Enum": ".enum",
    "EnumOption": ".enum_option",
    "EvaluationSet": ".evaluation_set",
    "EvaluationSetEntity": ".evaluation_set_entity",
    "EvaluationSetEntity_Classifier": ".evaluation_set_entity",
    "EvaluationSetEntity_Extractor": ".evaluation_set_entity",
    "EvaluationSetEntity_Splitter": ".evaluation_set_entity",
    "EvaluationSetItem": ".evaluation_set_item",
    "EvaluationSetItemSummary": ".evaluation_set_item_summary",
    "EvaluationSetRun": ".evaluation_set_run",
    "EvaluationSetRunEntity": ".evaluation_set_run_entity",
    "EvaluationSetRunEntityVersion": ".evaluation_set_run_entity_version",
    "EvaluationSetRunEntityVersion_ClassifierVersion": ".evaluation_set_run_entity_version",
    "EvaluationSetRunEntityVersion_ExtractorVersion": ".evaluation_set_run_entity_version",
    "EvaluationSetRunEntityVersion_SplitterVersion": ".evaluation_set_run_entity_version",
    "EvaluationSetRunEntity_Classifier": ".evaluation_set_run_entity",
    "EvaluationSetRunEntity_Extractor": ".evaluation_set_run_entity",
    "EvaluationSetRunEntity_Splitter": ".evaluation_set_run_entity",
    "EvaluationSetRunMetrics": ".evaluation_set_run_metrics",
    "EvaluationSetRunOptions": ".evaluation_set_run_options",
    "ExcelSheetRange": ".excel_sheet_range",
    "ExternalDataValidationResult": ".external_data_validation_result",
    "ExternalDataValidationResultResponse": ".external_data_validation_result_response",
    "ExternalDataValidationStepRun": ".external_data_validation_step_run",
    "ExternalDataValidationStepRunStep": ".external_data_validation_step_run_step",
    "ExtractAdvancedOptions": ".extract_advanced_options",
    "ExtractAdvancedOptionsArrayCitationStrategy": ".extract_advanced_options_array_citation_strategy",
    "ExtractAdvancedOptionsExcelSheetSelectionStrategy": ".extract_advanced_options_excel_sheet_selection_strategy",
    "ExtractAdvancedOptionsReviewAgent": ".extract_advanced_options_review_agent",
    "ExtractBaseProcessor": ".extract_base_processor",
    "ExtractChunkingOptions": ".extract_chunking_options",
    "ExtractChunkingOptionsChunkSelectionStrategy": ".extract_chunking_options_chunk_selection_strategy",
    "ExtractChunkingOptionsChunkingStrategy": ".extract_chunking_options_chunking_strategy",
    "ExtractConfig": ".extract_config",
    "ExtractConfigJson": ".extract_config_json",
    "ExtractConfigLegacy": ".extract_config_legacy",
    "ExtractConfigLegacyBaseProcessor": ".extract_config_legacy_base_processor",
    "ExtractOutput": ".extract_output",
    "ExtractOutputEdits": ".extract_output_edits",
    "ExtractOutputJson": ".extract_output_json",
    "ExtractOutputLegacy": ".extract_output_legacy",
    "ExtractOutputMetadata": ".extract_output_metadata",
    "ExtractOutputMetadataValue": ".extract_output_metadata_value",
    "ExtractOverrideConfigJson": ".extract_override_config_json",
    "ExtractRequestExtractor": ".extract_request_extractor",
    "ExtractRequestFile": ".extract_request_file",
    "ExtractResult": ".extract_result",
    "ExtractRun": ".extract_run",
    "ExtractRunFailedWebhookEvent": ".extract_run_failed_webhook_event",
    "ExtractRunProcessedWebhookEvent": ".extract_run_processed_webhook_event",
    "ExtractRunSummary": ".extract_run_summary",
    "ExtractStepRun": ".extract_step_run",
    "ExtractStepRunStep": ".extract_step_run_step",
    "ExtractionField": ".extraction_field",
    "ExtractionFieldResult": ".extraction_field_result",
    "ExtractionFieldResultReference": ".extraction_field_result_reference",
    "ExtractionFieldResultReferenceBoundingBoxesItem": ".extraction_field_result_reference_bounding_boxes_item",
    "ExtractionFieldResultType": ".extraction_field_result_type",
    "ExtractionFieldType": ".extraction_field_type",
    "Extractor": ".extractor",
    "ExtractorCreatedWebhookEvent": ".extractor_created_webhook_event",
    "ExtractorDeletedWebhookEvent": ".extractor_deleted_webhook_event",
    "ExtractorDraftUpdatedWebhookEvent": ".extractor_draft_updated_webhook_event",
    "ExtractorSummary": ".extractor_summary",
    "ExtractorUpdatedWebhookEvent": ".extractor_updated_webhook_event",
    "ExtractorVersion": ".extractor_version",
    "ExtractorVersionPublishedWebhookEvent": ".extractor_version_published_webhook_event",
    "ExtractorVersionSummary": ".extractor_version_summary",
    "FigureDetails": ".figure_details",
    "FigureDetailsFigureType": ".figure_details_figure_type",
    "File": ".file",
    "FileContents": ".file_contents",
    "FileContentsPagesItem": ".file_contents_pages_item",
    "FileContentsSectionsItem": ".file_contents_sections_item",
    "FileContentsSheetsItem": ".file_contents_sheets_item",
    "FileFromId": ".file_from_id",
    "FileFromText": ".file_from_text",
    "FileFromUrl": ".file_from_url",
    "FileMetadata": ".file_metadata",
    "FileSummary": ".file_summary",
    "FileType": ".file_type",
    "Insight": ".insight",
    "JsonObject": ".json_object",
    "LegacyBatchProcessorRun": ".legacy_batch_processor_run",
    "LegacyBatchProcessorRunMetrics": ".legacy_batch_processor_run_metrics",
    "LegacyBatchProcessorRunOptions": ".legacy_batch_processor_run_options",
    "LegacyBatchProcessorRunSource": ".legacy_batch_processor_run_source",
    "LegacyBatchProcessorRunStatus": ".legacy_batch_processor_run_status",
    "LegacyClassification": ".legacy_classification",
    "LegacyClassificationAdvancedOptions": ".legacy_classification_advanced_options",
    "LegacyClassificationAdvancedOptionsContext": ".legacy_classification_advanced_options_context",
    "LegacyClassificationConfig": ".legacy_classification_config",
    "LegacyClassificationConfigBaseProcessor": ".legacy_classification_config_base_processor",
    "LegacyClassifierOutput": ".legacy_classifier_output",
    "LegacyDocumentProcessorRunCredits": ".legacy_document_processor_run_credits",
    "LegacyError": ".legacy_error",
    "LegacyExtendError": ".legacy_extend_error",
    "LegacyExtractChunkingOptions": ".legacy_extract_chunking_options",
    "LegacyExtractChunkingOptionsChunkSelectionStrategy": ".legacy_extract_chunking_options_chunk_selection_strategy",
    "LegacyExtractChunkingOptionsChunkingStrategy": ".legacy_extract_chunking_options_chunking_strategy",
    "LegacyExtractionAdvancedOptions": ".legacy_extraction_advanced_options",
    "LegacyExtractionAdvancedOptionsArrayCitationStrategy": ".legacy_extraction_advanced_options_array_citation_strategy",
    "LegacyExtractionAdvancedOptionsExcelSheetSelectionStrategy": ".legacy_extraction_advanced_options_excel_sheet_selection_strategy",
    "LegacyExtractionAdvancedOptionsReviewAgent": ".legacy_extraction_advanced_options_review_agent",
    "LegacyExtractionConfig": ".legacy_extraction_config",
    "LegacyExtractionConfigBaseProcessor": ".legacy_extraction_config_base_processor",
    "LegacyExtractionField": ".legacy_extraction_field",
    "LegacyExtractionFieldResult": ".legacy_extraction_field_result",
    "LegacyExtractionFieldResultType": ".legacy_extraction_field_result_type",
    "LegacyExtractionFieldType": ".legacy_extraction_field_type",
    "LegacyExtractionOutput": ".legacy_extraction_output",
    "LegacyExtractionOutputEdits": ".legacy_extraction_output_edits",
    "LegacyFieldsArrayOutput": ".legacy_fields_array_output",
    "LegacyJsonObject": ".legacy_json_object",
    "LegacyJsonOutput": ".legacy_json_output",
    "LegacyJsonOutputMetadataValue": ".legacy_json_output_metadata_value",
    "LegacyJsonOutputMetadataValueCitationsItem": ".legacy_json_output_metadata_value_citations_item",
    "LegacyJsonOutputMetadataValueCitationsItemPolygonItem": ".legacy_json_output_metadata_value_citations_item_polygon_item",
    "LegacyListProcessorsProcessor": ".legacy_list_processors_processor",
    "LegacyListProcessorsProcessorVersion": ".legacy_list_processors_processor_version",
    "LegacyListProcessorsResponse": ".legacy_list_processors_response",
    "LegacyMaxPageSize": ".legacy_max_page_size",
    "LegacyNextPageToken": ".legacy_next_page_token",
    "LegacyProcessor": ".legacy_processor",
    "LegacyProcessorId": ".legacy_processor_id",
    "LegacyProcessorOutput": ".legacy_processor_output",
    "LegacyProcessorRun": ".legacy_processor_run",
    "LegacyProcessorRunConfig": ".legacy_processor_run_config",
    "LegacyProcessorRunConfig_Classify": ".legacy_processor_run_config",
    "LegacyProcessorRunConfig_Extract": ".legacy_processor_run_config",
    "LegacyProcessorRunConfig_Splitter": ".legacy_processor_run_config",
    "LegacyProcessorRunFileInput": ".legacy_processor_run_file_input",
    "LegacyProcessorRunMergedProcessorsItem": ".legacy_processor_run_merged_processors_item",
    "LegacyProcessorRunSummary": ".legacy_processor_run_summary",
    "LegacyProcessorRunSummaryType": ".legacy_processor_run_summary_type",
    "LegacyProcessorRunType": ".legacy_processor_run_type",
    "LegacyProcessorStatus": ".legacy_processor_status",
    "LegacyProcessorType": ".legacy_processor_type",
    "LegacyProcessorVersion": ".legacy_processor_version",
    "LegacyProcessorVersionConfig": ".legacy_processor_version_config",
    "LegacyProcessorVersionConfig_Classify": ".legacy_processor_version_config",
    "LegacyProcessorVersionConfig_Extract": ".legacy_processor_version_config",
    "LegacyProcessorVersionConfig_Splitter": ".legacy_processor_version_config",
    "LegacyProvidedClassifierOutput": ".legacy_provided_classifier_output",
    "LegacyProvidedExtractionFieldResult": ".legacy_provided_extraction_field_result",
    "LegacyProvidedExtractionFieldResultType": ".legacy_provided_extraction_field_result_type",
    "LegacyProvidedExtractionOutput": ".legacy_provided_extraction_output",
    "LegacyProvidedFieldsArrayOutput": ".legacy_provided_fields_array_output",
    "LegacyProvidedJsonOutput": ".legacy_provided_json_output",
    "LegacyProvidedProcessorOutput": ".legacy_provided_processor_output",
    "LegacyProvidedSplitterOutput": ".legacy_provided_splitter_output",
    "LegacyProvidedSplitterOutputSplitsItem": ".legacy_provided_splitter_output_splits_item",
    "LegacySortByEnum": ".legacy_sort_by_enum",
    "LegacySortDirEnum": ".legacy_sort_dir_enum",
    "LegacySplitterAdvancedOptions": ".legacy_splitter_advanced_options",
    "LegacySplitterAdvancedOptionsSplitMethod": ".legacy_splitter_advanced_options_split_method",
    "LegacySplitterConfig": ".legacy_splitter_config",
    "LegacySplitterConfigBaseProcessor": ".legacy_splitter_config_base_processor",
    "LegacySplitterOutput": ".legacy_splitter_output",
    "LegacySplitterOutputSplitsItem": ".legacy_splitter_output_splits_item",
    "MaxPageSize": ".max_page_size",
    "MergeExtractResult": ".merge_extract_result",
    "MergeExtractResultMergedExtractorsItem": ".merge_extract_result_merged_extractors_item",
    "MergeExtractStepRun": ".merge_extract_step_run",
    "MergeExtractStepRunStep": ".merge_extract_step_run_step",
    "NextPageToken": ".next_page_token",
    "PageRanges": ".page_ranges",
    "PageRangesItem": ".page_ranges_item",
    "ParentSplit": ".parent_split",
    "ParseConfig": ".parse_config",
    "ParseConfigAdvancedOptions": ".parse_config_advanced_options",
    "ParseConfigAdvancedOptionsExcelParsingMode": ".parse_config_advanced_options_excel_parsing_mode",
    "ParseConfigAdvancedOptionsReturnOcr": ".parse_config_advanced_options_return_ocr",
    "ParseConfigBlockOptions": ".parse_config_block_options",
    "ParseConfigBlockOptionsFigures": ".parse_config_block_options_figures",
    "ParseConfigBlockOptionsTables": ".parse_config_block_options_tables",
    "ParseConfigBlockOptionsTablesAgentic": ".parse_config_block_options_tables_agentic",
    "ParseConfigBlockOptionsTablesTargetFormat": ".parse_config_block_options_tables_target_format",
    "ParseConfigBlockOptionsText": ".parse_config_block_options_text",
    "ParseConfigBlockOptionsTextAgentic": ".parse_config_block_options_text_agentic",
    "ParseConfigChunkingStrategy": ".parse_config_chunking_strategy",
    "ParseConfigChunkingStrategyOptions": ".parse_config_chunking_strategy_options",
    "ParseConfigChunkingStrategyType": ".parse_config_chunking_strategy_type",
    "ParseConfigEngine": ".parse_config_engine",
    "ParseConfigTarget": ".parse_config_target",
    "ParseRequestFile": ".parse_request_file",
    "ParseRequestResponseType": ".parse_request_response_type",
    "ParseResult": ".parse_result",
    "ParseRun": ".parse_run",
    "ParseRunFailedWebhookEvent": ".parse_run_failed_webhook_event",
    "ParseRunMetrics": ".parse_run_metrics",
    "ParseRunOutput": ".parse_run_output",
    "ParseRunOutputOcr": ".parse_run_output_ocr",
    "ParseRunOutputOcrWordsItem": ".parse_run_output_ocr_words_item",
    "ParseRunProcessedWebhookEvent": ".parse_run_processed_webhook_event",
    "ParseRunStatus": ".parse_run_status",
    "ParseRunStatusEnum": ".parse_run_status_enum",
    "ParseRunStatusStatus": ".parse_run_status_status",
    "ParseStepRun": ".parse_step_run",
    "ParseStepRunStep": ".parse_step_run_step",
    "Polygon": ".polygon",
    "ProcessorRunStatus": ".processor_run_status",
    "ProcessorVersionString": ".processor_version_string",
    "ProvidedClassifyOutput": ".provided_classify_output",
    "ProvidedExtractOutput": ".provided_extract_output",
    "ProvidedProcessorOutput": ".provided_processor_output",
    "ProvidedSplitOutput": ".provided_split_output",
    "ProvidedSplitOutputSplitsItem": ".provided_split_output_splits_item",
    "ReleaseType": ".release_type",
    "RuleValidationResult": ".rule_validation_result",
    "RuleValidationResultRulesItem": ".rule_validation_result_rules_item",
    "RuleValidationResultRulesItemFailureReason": ".rule_validation_result_rules_item_failure_reason",
    "RuleValidationStepRun": ".rule_validation_step_run",
    "RuleValidationStepRunStep": ".rule_validation_step_run_step",
    "RunMetadata": ".run_metadata",
    "RunPriority": ".run_priority",
    "RunSecrets": ".run_secrets",
    "RunSource": ".run_source",
    "RunSourceId": ".run_source_id",
    "RunUsage": ".run_usage",
    "SortBy": ".sort_by",
    "SortDir": ".sort_dir",
    "SplitAdvancedOptions": ".split_advanced_options",
    "SplitAdvancedOptionsSplitMethod": ".split_advanced_options_split_method",
    "SplitBaseProcessor": ".split_base_processor",
    "SplitConfig": ".split_config",
    "SplitOutput": ".split_output",
    "SplitOutputSplitsItem": ".split_output_splits_item",
    "SplitOverrideConfig": ".split_override_config",
    "SplitRequestFile": ".split_request_file",
    "SplitRequestSplitter": ".split_request_splitter",
    "SplitResult": ".split_result",
    "SplitRun": ".split_run",
    "SplitRunFailedWebhookEvent": ".split_run_failed_webhook_event",
    "SplitRunProcessedWebhookEvent": ".split_run_processed_webhook_event",
    "SplitRunSummary": ".split_run_summary",
    "SplitStepRun": ".split_step_run",
    "SplitStepRunStep": ".split_step_run_step",
    "Splitter": ".splitter",
    "SplitterCreatedWebhookEvent": ".splitter_created_webhook_event",
    "SplitterDeletedWebhookEvent": ".splitter_deleted_webhook_event",
    "SplitterDraftUpdatedWebhookEvent": ".splitter_draft_updated_webhook_event",
    "SplitterSummary": ".splitter_summary",
    "SplitterUpdatedWebhookEvent": ".splitter_updated_webhook_event",
    "SplitterVersion": ".splitter_version",
    "SplitterVersionPublishedWebhookEvent": ".splitter_version_published_webhook_event",
    "SplitterVersionSummary": ".splitter_version_summary",
    "StepRun": ".step_run",
    "StepRunBase": ".step_run_base",
    "StepRunBaseStatus": ".step_run_base_status",
    "TableCellDetails": ".table_cell_details",
    "TableDetails": ".table_details",
    "TooManyRequestsErrorBody": ".too_many_requests_error_body",
    "UpdatedAt": ".updated_at",
    "VersionDescription": ".version_description",
    "WebhookAdvancedOptions": ".webhook_advanced_options",
    "WebhookEndpoint": ".webhook_endpoint",
    "WebhookEndpointCreate": ".webhook_endpoint_create",
    "WebhookEndpointEventType": ".webhook_endpoint_event_type",
    "WebhookEndpointStatus": ".webhook_endpoint_status",
    "WebhookEvent": ".webhook_event",
    "WebhookEvent_ClassifierCreated": ".webhook_event",
    "WebhookEvent_ClassifierDeleted": ".webhook_event",
    "WebhookEvent_ClassifierDraftUpdated": ".webhook_event",
    "WebhookEvent_ClassifierUpdated": ".webhook_event",
    "WebhookEvent_ClassifierVersionPublished": ".webhook_event",
    "WebhookEvent_ClassifyRunFailed": ".webhook_event",
    "WebhookEvent_ClassifyRunProcessed": ".webhook_event",
    "WebhookEvent_EditRunFailed": ".webhook_event",
    "WebhookEvent_EditRunProcessed": ".webhook_event",
    "WebhookEvent_ExtractRunFailed": ".webhook_event",
    "WebhookEvent_ExtractRunProcessed": ".webhook_event",
    "WebhookEvent_ExtractorCreated": ".webhook_event",
    "WebhookEvent_ExtractorDeleted": ".webhook_event",
    "WebhookEvent_ExtractorDraftUpdated": ".webhook_event",
    "WebhookEvent_ExtractorUpdated": ".webhook_event",
    "WebhookEvent_ExtractorVersionPublished": ".webhook_event",
    "WebhookEvent_ParseRunFailed": ".webhook_event",
    "WebhookEvent_ParseRunProcessed": ".webhook_event",
    "WebhookEvent_SplitRunFailed": ".webhook_event",
    "WebhookEvent_SplitRunProcessed": ".webhook_event",
    "WebhookEvent_SplitterCreated": ".webhook_event",
    "WebhookEvent_SplitterDeleted": ".webhook_event",
    "WebhookEvent_SplitterDraftUpdated": ".webhook_event",
    "WebhookEvent_SplitterUpdated": ".webhook_event",
    "WebhookEvent_SplitterVersionPublished": ".webhook_event",
    "WebhookEvent_WorkflowCreated": ".webhook_event",
    "WebhookEvent_WorkflowDeleted": ".webhook_event",
    "WebhookEvent_WorkflowDeployed": ".webhook_event",
    "WebhookEvent_WorkflowRunCancelled": ".webhook_event",
    "WebhookEvent_WorkflowRunCompleted": ".webhook_event",
    "WebhookEvent_WorkflowRunFailed": ".webhook_event",
    "WebhookEvent_WorkflowRunNeedsReview": ".webhook_event",
    "WebhookEvent_WorkflowRunRejected": ".webhook_event",
    "WebhookEvent_WorkflowRunStepRunProcessed": ".webhook_event",
    "WebhookPayloadFormat": ".webhook_payload_format",
    "WebhookPayloadOptions": ".webhook_payload_options",
    "WebhookSubscription": ".webhook_subscription",
    "WebhookSubscriptionEventType": ".webhook_subscription_event_type",
    "WebhookSubscriptionResourceType": ".webhook_subscription_resource_type",
    "Workflow": ".workflow",
    "WorkflowCreatedWebhookEvent": ".workflow_created_webhook_event",
    "WorkflowDeletedWebhookEvent": ".workflow_deleted_webhook_event",
    "WorkflowDeployedWebhookEvent": ".workflow_deployed_webhook_event",
    "WorkflowReference": ".workflow_reference",
    "WorkflowRun": ".workflow_run",
    "WorkflowRunCancelledWebhookEvent": ".workflow_run_cancelled_webhook_event",
    "WorkflowRunCompletedWebhookEvent": ".workflow_run_completed_webhook_event",
    "WorkflowRunFailedWebhookEvent": ".workflow_run_failed_webhook_event",
    "WorkflowRunNeedsReviewWebhookEvent": ".workflow_run_needs_review_webhook_event",
    "WorkflowRunRejectedWebhookEvent": ".workflow_run_rejected_webhook_event",
    "WorkflowRunStatus": ".workflow_run_status",
    "WorkflowRunStepRunProcessedWebhookEvent": ".workflow_run_step_run_processed_webhook_event",
    "WorkflowRunSummary": ".workflow_run_summary",
    "WorkflowStepBase": ".workflow_step_base",
    "WorkflowSummary": ".workflow_summary",
    "WorkflowVersion": ".workflow_version",
    "WorkflowVersionSummary": ".workflow_version_summary",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "ApiError",
    "ApiVersionEnum",
    "ArrayStrategy",
    "ArrayStrategyType",
    "BatchProcessorRun",
    "BatchProcessorRunMetrics",
    "BatchProcessorRunOptions",
    "BatchProcessorRunSource",
    "BatchProcessorRunStatus",
    "BatchRun",
    "BatchRunEntity",
    "BatchRunEntityVersion",
    "BatchRunEntityVersion_ClassifierVersion",
    "BatchRunEntityVersion_ExtractorVersion",
    "BatchRunEntityVersion_SplitterVersion",
    "BatchRunEntity_Classifier",
    "BatchRunEntity_Extractor",
    "BatchRunEntity_Splitter",
    "BatchRunMetrics",
    "BatchRunStatus",
    "Block",
    "BlockDetails",
    "BlockMetadata",
    "BlockMetadataPage",
    "BlockPolygonItem",
    "BlockType",
    "BoundingBox",
    "Chunk",
    "ChunkMetadata",
    "ChunkMetadataPageRange",
    "ChunkType",
    "Citation",
    "CitationPage",
    "Classification",
    "Classifications",
    "Classifier",
    "ClassifierCreatedWebhookEvent",
    "ClassifierDeletedWebhookEvent",
    "ClassifierDraftUpdatedWebhookEvent",
    "ClassifierSummary",
    "ClassifierUpdatedWebhookEvent",
    "ClassifierVersion",
    "ClassifierVersionPublishedWebhookEvent",
    "ClassifierVersionSummary",
    "ClassifyAdvancedOptions",
    "ClassifyAdvancedOptionsContext",
    "ClassifyBaseProcessor",
    "ClassifyConfig",
    "ClassifyOutput",
    "ClassifyOverrideConfig",
    "ClassifyRequestClassifier",
    "ClassifyRequestFile",
    "ClassifyResult",
    "ClassifyRun",
    "ClassifyRunFailedWebhookEvent",
    "ClassifyRunProcessedWebhookEvent",
    "ClassifyRunSummary",
    "ClassifyStepRun",
    "ClassifyStepRunStep",
    "ConditionalExtractResult",
    "ConditionalExtractStepRun",
    "ConditionalExtractStepRunStep",
    "CreatedAt",
    "EditBoundingBox",
    "EditConfig",
    "EditConfigAdvancedOptions",
    "EditJson",
    "EditJsonExtendEditFieldType",
    "EditObjectJson",
    "EditRequestFile",
    "EditRootJson",
    "EditRun",
    "EditRunFailedWebhookEvent",
    "EditRunMetrics",
    "EditRunOutput",
    "EditRunOutputEditedFile",
    "EditRunProcessedWebhookEvent",
    "EditRunStatus",
    "EditTextOptions",
    "EmptyBlockDetails",
    "Enum",
    "EnumOption",
    "EvaluationSet",
    "EvaluationSetEntity",
    "EvaluationSetEntity_Classifier",
    "EvaluationSetEntity_Extractor",
    "EvaluationSetEntity_Splitter",
    "EvaluationSetItem",
    "EvaluationSetItemSummary",
    "EvaluationSetRun",
    "EvaluationSetRunEntity",
    "EvaluationSetRunEntityVersion",
    "EvaluationSetRunEntityVersion_ClassifierVersion",
    "EvaluationSetRunEntityVersion_ExtractorVersion",
    "EvaluationSetRunEntityVersion_SplitterVersion",
    "EvaluationSetRunEntity_Classifier",
    "EvaluationSetRunEntity_Extractor",
    "EvaluationSetRunEntity_Splitter",
    "EvaluationSetRunMetrics",
    "EvaluationSetRunOptions",
    "ExcelSheetRange",
    "ExternalDataValidationResult",
    "ExternalDataValidationResultResponse",
    "ExternalDataValidationStepRun",
    "ExternalDataValidationStepRunStep",
    "ExtractAdvancedOptions",
    "ExtractAdvancedOptionsArrayCitationStrategy",
    "ExtractAdvancedOptionsExcelSheetSelectionStrategy",
    "ExtractAdvancedOptionsReviewAgent",
    "ExtractBaseProcessor",
    "ExtractChunkingOptions",
    "ExtractChunkingOptionsChunkSelectionStrategy",
    "ExtractChunkingOptionsChunkingStrategy",
    "ExtractConfig",
    "ExtractConfigJson",
    "ExtractConfigLegacy",
    "ExtractConfigLegacyBaseProcessor",
    "ExtractOutput",
    "ExtractOutputEdits",
    "ExtractOutputJson",
    "ExtractOutputLegacy",
    "ExtractOutputMetadata",
    "ExtractOutputMetadataValue",
    "ExtractOverrideConfigJson",
    "ExtractRequestExtractor",
    "ExtractRequestFile",
    "ExtractResult",
    "ExtractRun",
    "ExtractRunFailedWebhookEvent",
    "ExtractRunProcessedWebhookEvent",
    "ExtractRunSummary",
    "ExtractStepRun",
    "ExtractStepRunStep",
    "ExtractionField",
    "ExtractionFieldResult",
    "ExtractionFieldResultReference",
    "ExtractionFieldResultReferenceBoundingBoxesItem",
    "ExtractionFieldResultType",
    "ExtractionFieldType",
    "Extractor",
    "ExtractorCreatedWebhookEvent",
    "ExtractorDeletedWebhookEvent",
    "ExtractorDraftUpdatedWebhookEvent",
    "ExtractorSummary",
    "ExtractorUpdatedWebhookEvent",
    "ExtractorVersion",
    "ExtractorVersionPublishedWebhookEvent",
    "ExtractorVersionSummary",
    "FigureDetails",
    "FigureDetailsFigureType",
    "File",
    "FileContents",
    "FileContentsPagesItem",
    "FileContentsSectionsItem",
    "FileContentsSheetsItem",
    "FileFromId",
    "FileFromText",
    "FileFromUrl",
    "FileMetadata",
    "FileSummary",
    "FileType",
    "Insight",
    "JsonObject",
    "LegacyBatchProcessorRun",
    "LegacyBatchProcessorRunMetrics",
    "LegacyBatchProcessorRunOptions",
    "LegacyBatchProcessorRunSource",
    "LegacyBatchProcessorRunStatus",
    "LegacyClassification",
    "LegacyClassificationAdvancedOptions",
    "LegacyClassificationAdvancedOptionsContext",
    "LegacyClassificationConfig",
    "LegacyClassificationConfigBaseProcessor",
    "LegacyClassifierOutput",
    "LegacyDocumentProcessorRunCredits",
    "LegacyError",
    "LegacyExtendError",
    "LegacyExtractChunkingOptions",
    "LegacyExtractChunkingOptionsChunkSelectionStrategy",
    "LegacyExtractChunkingOptionsChunkingStrategy",
    "LegacyExtractionAdvancedOptions",
    "LegacyExtractionAdvancedOptionsArrayCitationStrategy",
    "LegacyExtractionAdvancedOptionsExcelSheetSelectionStrategy",
    "LegacyExtractionAdvancedOptionsReviewAgent",
    "LegacyExtractionConfig",
    "LegacyExtractionConfigBaseProcessor",
    "LegacyExtractionField",
    "LegacyExtractionFieldResult",
    "LegacyExtractionFieldResultType",
    "LegacyExtractionFieldType",
    "LegacyExtractionOutput",
    "LegacyExtractionOutputEdits",
    "LegacyFieldsArrayOutput",
    "LegacyJsonObject",
    "LegacyJsonOutput",
    "LegacyJsonOutputMetadataValue",
    "LegacyJsonOutputMetadataValueCitationsItem",
    "LegacyJsonOutputMetadataValueCitationsItemPolygonItem",
    "LegacyListProcessorsProcessor",
    "LegacyListProcessorsProcessorVersion",
    "LegacyListProcessorsResponse",
    "LegacyMaxPageSize",
    "LegacyNextPageToken",
    "LegacyProcessor",
    "LegacyProcessorId",
    "LegacyProcessorOutput",
    "LegacyProcessorRun",
    "LegacyProcessorRunConfig",
    "LegacyProcessorRunConfig_Classify",
    "LegacyProcessorRunConfig_Extract",
    "LegacyProcessorRunConfig_Splitter",
    "LegacyProcessorRunFileInput",
    "LegacyProcessorRunMergedProcessorsItem",
    "LegacyProcessorRunSummary",
    "LegacyProcessorRunSummaryType",
    "LegacyProcessorRunType",
    "LegacyProcessorStatus",
    "LegacyProcessorType",
    "LegacyProcessorVersion",
    "LegacyProcessorVersionConfig",
    "LegacyProcessorVersionConfig_Classify",
    "LegacyProcessorVersionConfig_Extract",
    "LegacyProcessorVersionConfig_Splitter",
    "LegacyProvidedClassifierOutput",
    "LegacyProvidedExtractionFieldResult",
    "LegacyProvidedExtractionFieldResultType",
    "LegacyProvidedExtractionOutput",
    "LegacyProvidedFieldsArrayOutput",
    "LegacyProvidedJsonOutput",
    "LegacyProvidedProcessorOutput",
    "LegacyProvidedSplitterOutput",
    "LegacyProvidedSplitterOutputSplitsItem",
    "LegacySortByEnum",
    "LegacySortDirEnum",
    "LegacySplitterAdvancedOptions",
    "LegacySplitterAdvancedOptionsSplitMethod",
    "LegacySplitterConfig",
    "LegacySplitterConfigBaseProcessor",
    "LegacySplitterOutput",
    "LegacySplitterOutputSplitsItem",
    "MaxPageSize",
    "MergeExtractResult",
    "MergeExtractResultMergedExtractorsItem",
    "MergeExtractStepRun",
    "MergeExtractStepRunStep",
    "NextPageToken",
    "PageRanges",
    "PageRangesItem",
    "ParentSplit",
    "ParseConfig",
    "ParseConfigAdvancedOptions",
    "ParseConfigAdvancedOptionsExcelParsingMode",
    "ParseConfigAdvancedOptionsReturnOcr",
    "ParseConfigBlockOptions",
    "ParseConfigBlockOptionsFigures",
    "ParseConfigBlockOptionsTables",
    "ParseConfigBlockOptionsTablesAgentic",
    "ParseConfigBlockOptionsTablesTargetFormat",
    "ParseConfigBlockOptionsText",
    "ParseConfigBlockOptionsTextAgentic",
    "ParseConfigChunkingStrategy",
    "ParseConfigChunkingStrategyOptions",
    "ParseConfigChunkingStrategyType",
    "ParseConfigEngine",
    "ParseConfigTarget",
    "ParseRequestFile",
    "ParseRequestResponseType",
    "ParseResult",
    "ParseRun",
    "ParseRunFailedWebhookEvent",
    "ParseRunMetrics",
    "ParseRunOutput",
    "ParseRunOutputOcr",
    "ParseRunOutputOcrWordsItem",
    "ParseRunProcessedWebhookEvent",
    "ParseRunStatus",
    "ParseRunStatusEnum",
    "ParseRunStatusStatus",
    "ParseStepRun",
    "ParseStepRunStep",
    "Polygon",
    "ProcessorRunStatus",
    "ProcessorVersionString",
    "ProvidedClassifyOutput",
    "ProvidedExtractOutput",
    "ProvidedProcessorOutput",
    "ProvidedSplitOutput",
    "ProvidedSplitOutputSplitsItem",
    "ReleaseType",
    "RuleValidationResult",
    "RuleValidationResultRulesItem",
    "RuleValidationResultRulesItemFailureReason",
    "RuleValidationStepRun",
    "RuleValidationStepRunStep",
    "RunMetadata",
    "RunPriority",
    "RunSecrets",
    "RunSource",
    "RunSourceId",
    "RunUsage",
    "SortBy",
    "SortDir",
    "SplitAdvancedOptions",
    "SplitAdvancedOptionsSplitMethod",
    "SplitBaseProcessor",
    "SplitConfig",
    "SplitOutput",
    "SplitOutputSplitsItem",
    "SplitOverrideConfig",
    "SplitRequestFile",
    "SplitRequestSplitter",
    "SplitResult",
    "SplitRun",
    "SplitRunFailedWebhookEvent",
    "SplitRunProcessedWebhookEvent",
    "SplitRunSummary",
    "SplitStepRun",
    "SplitStepRunStep",
    "Splitter",
    "SplitterCreatedWebhookEvent",
    "SplitterDeletedWebhookEvent",
    "SplitterDraftUpdatedWebhookEvent",
    "SplitterSummary",
    "SplitterUpdatedWebhookEvent",
    "SplitterVersion",
    "SplitterVersionPublishedWebhookEvent",
    "SplitterVersionSummary",
    "StepRun",
    "StepRunBase",
    "StepRunBaseStatus",
    "TableCellDetails",
    "TableDetails",
    "TooManyRequestsErrorBody",
    "UpdatedAt",
    "VersionDescription",
    "WebhookAdvancedOptions",
    "WebhookEndpoint",
    "WebhookEndpointCreate",
    "WebhookEndpointEventType",
    "WebhookEndpointStatus",
    "WebhookEvent",
    "WebhookEvent_ClassifierCreated",
    "WebhookEvent_ClassifierDeleted",
    "WebhookEvent_ClassifierDraftUpdated",
    "WebhookEvent_ClassifierUpdated",
    "WebhookEvent_ClassifierVersionPublished",
    "WebhookEvent_ClassifyRunFailed",
    "WebhookEvent_ClassifyRunProcessed",
    "WebhookEvent_EditRunFailed",
    "WebhookEvent_EditRunProcessed",
    "WebhookEvent_ExtractRunFailed",
    "WebhookEvent_ExtractRunProcessed",
    "WebhookEvent_ExtractorCreated",
    "WebhookEvent_ExtractorDeleted",
    "WebhookEvent_ExtractorDraftUpdated",
    "WebhookEvent_ExtractorUpdated",
    "WebhookEvent_ExtractorVersionPublished",
    "WebhookEvent_ParseRunFailed",
    "WebhookEvent_ParseRunProcessed",
    "WebhookEvent_SplitRunFailed",
    "WebhookEvent_SplitRunProcessed",
    "WebhookEvent_SplitterCreated",
    "WebhookEvent_SplitterDeleted",
    "WebhookEvent_SplitterDraftUpdated",
    "WebhookEvent_SplitterUpdated",
    "WebhookEvent_SplitterVersionPublished",
    "WebhookEvent_WorkflowCreated",
    "WebhookEvent_WorkflowDeleted",
    "WebhookEvent_WorkflowDeployed",
    "WebhookEvent_WorkflowRunCancelled",
    "WebhookEvent_WorkflowRunCompleted",
    "WebhookEvent_WorkflowRunFailed",
    "WebhookEvent_WorkflowRunNeedsReview",
    "WebhookEvent_WorkflowRunRejected",
    "WebhookEvent_WorkflowRunStepRunProcessed",
    "WebhookPayloadFormat",
    "WebhookPayloadOptions",
    "WebhookSubscription",
    "WebhookSubscriptionEventType",
    "WebhookSubscriptionResourceType",
    "Workflow",
    "WorkflowCreatedWebhookEvent",
    "WorkflowDeletedWebhookEvent",
    "WorkflowDeployedWebhookEvent",
    "WorkflowReference",
    "WorkflowRun",
    "WorkflowRunCancelledWebhookEvent",
    "WorkflowRunCompletedWebhookEvent",
    "WorkflowRunFailedWebhookEvent",
    "WorkflowRunNeedsReviewWebhookEvent",
    "WorkflowRunRejectedWebhookEvent",
    "WorkflowRunStatus",
    "WorkflowRunStepRunProcessedWebhookEvent",
    "WorkflowRunSummary",
    "WorkflowStepBase",
    "WorkflowSummary",
    "WorkflowVersion",
    "WorkflowVersionSummary",
]
