# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..core.serialization import FieldMetadata
from ..types.legacy_classification_advanced_options_context import LegacyClassificationAdvancedOptionsContext
from .page_ranges import PageRangesParams


class LegacyClassificationAdvancedOptionsParams(typing_extensions.TypedDict):
    context: typing_extensions.NotRequired[LegacyClassificationAdvancedOptionsContext]
    """
    The context to use for classification.
    """

    advanced_multimodal_enabled: typing_extensions.NotRequired[
        typing_extensions.Annotated[bool, FieldMetadata(alias="advancedMultimodalEnabled")]
    ]
    """
    Enable advanced multimodal processing for better handling of visual elements during classification.
    """

    fixed_page_limit: typing_extensions.NotRequired[
        typing_extensions.Annotated[int, FieldMetadata(alias="fixedPageLimit")]
    ]
    """
    Limit processing to a specific number of pages from the beginning of the document. See [Page Ranges](https://docs.extend.ai/2026-02-09/product/page-ranges).
    """

    page_ranges: typing_extensions.NotRequired[
        typing_extensions.Annotated[PageRangesParams, FieldMetadata(alias="pageRanges")]
    ]
