# This file was auto-generated by Fern from our API Definition.

import typing

from .extract_config_json import ExtractConfigJson
from .extract_config_legacy import ExtractConfigLegacy

ExtractConfig = typing.Union[ExtractConfigJson, ExtractConfigLegacy]
