# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class LegacyErrorParams(typing_extensions.TypedDict):
    success: typing_extensions.NotRequired[bool]
    error: typing_extensions.NotRequired[str]
    """
    Error message
    """
