# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..types.json_object import JsonObject


class ExternalDataValidationResultResponseParams(typing_extensions.TypedDict):
    """
    The response from the external validation endpoint.
    """

    status: int
    """
    The HTTP status code returned by the external endpoint.
    """

    data: JsonObject
    """
    The JSON response body returned by the external endpoint.
    """
