# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from .chunk import ChunkParams
from .parse_run_output_ocr import ParseRunOutputOcrParams


class ParseRunOutputParams(typing_extensions.TypedDict):
    """
    The parse run output.

    **Availability:** Present when `status` is `"PROCESSED"` and the request was made without the `responseType=url` query parameter. Contains the parsed chunks.
    """

    chunks: typing.Sequence[ChunkParams]
    """
    An array of chunks that were parsed from the file.
    """

    ocr: typing_extensions.NotRequired[ParseRunOutputOcrParams]
    """
    Raw OCR data from the parsing process. Only included when `returnOcr` is configured in the parse config's advanced options.
    """
