# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel


class EvaluationSetRunOptions(UncheckedBaseModel):
    """
    The options for the evaluation set run.
    """

    fuzzy_match_fields: typing_extensions.Annotated[
        typing.Optional[typing.List[str]], FieldMetadata(alias="fuzzyMatchFields")
    ] = pydantic.Field(alias="fuzzyMatchFields", default=None)
    """
    The fields that were fuzzy matched.
    """

    exclude_fields: typing_extensions.Annotated[
        typing.Optional[typing.List[str]], FieldMetadata(alias="excludeFields")
    ] = pydantic.Field(alias="excludeFields", default=None)
    """
    The fields that were excluded from the run.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
