# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..core.serialization import FieldMetadata
from .parent_split import ParentSplitParams


class FileMetadataParams(typing_extensions.TypedDict):
    page_count: typing_extensions.NotRequired[typing_extensions.Annotated[float, FieldMetadata(alias="pageCount")]]
    """
    The number of pages in the file. This is only set for PDF/DOCX files.
    """

    parent_split: typing_extensions.NotRequired[
        typing_extensions.Annotated[ParentSplitParams, FieldMetadata(alias="parentSplit")]
    ]
