# This file was auto-generated by Fern from our API Definition.

import typing

from .parse_result import ParseResultParams
from .parse_step_run_step import ParseStepRunStepParams
from .step_run_base import StepRunBaseParams


class ParseStepRunParams(StepRunBaseParams):
    step: ParseStepRunStepParams
    result: typing.Optional[ParseResultParams]
    """
    The result of this parse step. Currently, `result` is always present for returned step runs. It is nullable to allow for future support of returning step runs with non-successful statuses.
    """
