# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2
from ...core.serialization import FieldMetadata
from ...core.unchecked_base_model import UncheckedBaseModel
from ...types.next_page_token import NextPageToken
from ...types.workflow_run_summary import WorkflowRunSummary


class WorkflowRunsListResponse(UncheckedBaseModel):
    object: typing.Literal["list"] = "list"
    data: typing.List[WorkflowRunSummary]
    next_page_token: typing_extensions.Annotated[
        typing.Optional[NextPageToken], FieldMetadata(alias="nextPageToken")
    ] = pydantic.Field(alias="nextPageToken", default=None)

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
