# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel


class ProvidedSplitOutputSplitsItem(UncheckedBaseModel):
    classification_id: typing_extensions.Annotated[str, FieldMetadata(alias="classificationId")] = pydantic.Field(
        alias="classificationId"
    )
    """
    ID of the classification type (defined in the splitter config)
    """

    type: str = pydantic.Field()
    """
    The type of the split document (defined in the splitter config), corresponds to the classificationId
    """

    start_page: typing_extensions.Annotated[int, FieldMetadata(alias="startPage")] = pydantic.Field(alias="startPage")
    """
    The start page of the split document
    """

    end_page: typing_extensions.Annotated[int, FieldMetadata(alias="endPage")] = pydantic.Field(alias="endPage")
    """
    The end page of the split document
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
