# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..types.json_object import JsonObject


class ProvidedExtractOutputParams(typing_extensions.TypedDict):
    """
    The expected extraction output.

    **Important:** Make sure to nest the JSON object conforming to the schema in a `value` object, and include all properties defined in the schema.
    """

    value: typing_extensions.NotRequired[JsonObject]
    """
    The expected extraction output, provided as a JSON object that conforms to the schema defined in the extractor config
    """
