# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..core.serialization import FieldMetadata


class BatchProcessorRunMetricsParams(typing_extensions.TypedDict):
    num_files: typing_extensions.NotRequired[typing_extensions.Annotated[float, FieldMetadata(alias="numFiles")]]
    """
    The total number of files processed in this batch run
    """

    num_pages: typing_extensions.NotRequired[typing_extensions.Annotated[float, FieldMetadata(alias="numPages")]]
    """
    The total number of pages processed in this batch run
    """
