# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..core.serialization import FieldMetadata
from .rule_validation_result_rules_item import RuleValidationResultRulesItemParams


class RuleValidationResultParams(typing_extensions.TypedDict):
    """
    The result of a rule validation step.
    """

    rules: typing.Sequence[RuleValidationResultRulesItemParams]
    """
    The list of validation rules and their results.
    """

    all_passed: typing_extensions.Annotated[bool, FieldMetadata(alias="allPassed")]
    """
    Indicates whether all validation rules passed.
    """
