# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions


class WorkflowParams(typing_extensions.TypedDict):
    object: typing.Literal["workflow"]
    """
    The type of object. In this case, it will always be `"workflow"`.
    """

    id: str
    """
    The ID of the workflow.
    
    Example: `"workflow_BMlfq_yWM3sT-ZzvCnA3f"`
    """

    name: str
    """
    The name of the workflow.
    
    Example: `"Invoice Processing"`
    """
