# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from .legacy_provided_splitter_output_splits_item import LegacyProvidedSplitterOutputSplitsItemParams


class LegacyProvidedSplitterOutputParams(typing_extensions.TypedDict):
    splits: typing.Sequence[LegacyProvidedSplitterOutputSplitsItemParams]
