# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ...core.serialization import FieldMetadata
from ...requests.legacy_batch_processor_run import LegacyBatchProcessorRunParams


class BatchProcessorRunGetResponseParams(typing_extensions.TypedDict):
    success: bool
    batch_processor_run: typing_extensions.Annotated[
        LegacyBatchProcessorRunParams, FieldMetadata(alias="batchProcessorRun")
    ]
