# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class LegacyJsonOutputMetadataValueCitationsItemPolygonItemParams(typing_extensions.TypedDict):
    x: float
    """
    X coordinate of the point
    """

    y: float
    """
    Y coordinate of the point
    """
