# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .api_error import ApiErrorParams
    from .array_strategy import ArrayStrategyParams
    from .batch_processor_run import BatchProcessorRunParams
    from .batch_processor_run_metrics import BatchProcessorRunMetricsParams
    from .batch_processor_run_options import BatchProcessorRunOptionsParams
    from .batch_run import BatchRunParams
    from .batch_run_entity import (
        BatchRunEntityParams,
        BatchRunEntity_ClassifierParams,
        BatchRunEntity_ExtractorParams,
        BatchRunEntity_SplitterParams,
    )
    from .batch_run_entity_version import (
        BatchRunEntityVersionParams,
        BatchRunEntityVersion_ClassifierVersionParams,
        BatchRunEntityVersion_ExtractorVersionParams,
        BatchRunEntityVersion_SplitterVersionParams,
    )
    from .batch_run_metrics import BatchRunMetricsParams
    from .block import BlockParams
    from .block_details import BlockDetailsParams
    from .block_metadata import BlockMetadataParams
    from .block_metadata_page import BlockMetadataPageParams
    from .block_polygon_item import BlockPolygonItemParams
    from .bounding_box import BoundingBoxParams
    from .chunk import ChunkParams
    from .chunk_metadata import ChunkMetadataParams
    from .chunk_metadata_page_range import ChunkMetadataPageRangeParams
    from .citation import CitationParams
    from .citation_page import CitationPageParams
    from .classification import ClassificationParams
    from .classifications import ClassificationsParams
    from .classifier import ClassifierParams
    from .classifier_created_webhook_event import ClassifierCreatedWebhookEventParams
    from .classifier_deleted_webhook_event import ClassifierDeletedWebhookEventParams
    from .classifier_draft_updated_webhook_event import ClassifierDraftUpdatedWebhookEventParams
    from .classifier_summary import ClassifierSummaryParams
    from .classifier_updated_webhook_event import ClassifierUpdatedWebhookEventParams
    from .classifier_version import ClassifierVersionParams
    from .classifier_version_published_webhook_event import ClassifierVersionPublishedWebhookEventParams
    from .classifier_version_summary import ClassifierVersionSummaryParams
    from .classify_advanced_options import ClassifyAdvancedOptionsParams
    from .classify_config import ClassifyConfigParams
    from .classify_output import ClassifyOutputParams
    from .classify_override_config import ClassifyOverrideConfigParams
    from .classify_request_classifier import ClassifyRequestClassifierParams
    from .classify_request_file import ClassifyRequestFileParams
    from .classify_result import ClassifyResultParams
    from .classify_run import ClassifyRunParams
    from .classify_run_failed_webhook_event import ClassifyRunFailedWebhookEventParams
    from .classify_run_processed_webhook_event import ClassifyRunProcessedWebhookEventParams
    from .classify_run_summary import ClassifyRunSummaryParams
    from .classify_step_run import ClassifyStepRunParams
    from .classify_step_run_step import ClassifyStepRunStepParams
    from .conditional_extract_result import ConditionalExtractResultParams
    from .conditional_extract_step_run import ConditionalExtractStepRunParams
    from .conditional_extract_step_run_step import ConditionalExtractStepRunStepParams
    from .edit_bounding_box import EditBoundingBoxParams
    from .edit_config import EditConfigParams
    from .edit_config_advanced_options import EditConfigAdvancedOptionsParams
    from .edit_json import EditJsonParams
    from .edit_object_json import EditObjectJsonParams
    from .edit_request_file import EditRequestFileParams
    from .edit_root_json import EditRootJsonParams
    from .edit_run import EditRunParams
    from .edit_run_failed_webhook_event import EditRunFailedWebhookEventParams
    from .edit_run_metrics import EditRunMetricsParams
    from .edit_run_output import EditRunOutputParams
    from .edit_run_output_edited_file import EditRunOutputEditedFileParams
    from .edit_run_processed_webhook_event import EditRunProcessedWebhookEventParams
    from .edit_text_options import EditTextOptionsParams
    from .enum import EnumParams
    from .enum_option import EnumOptionParams
    from .evaluation_set import EvaluationSetParams
    from .evaluation_set_entity import (
        EvaluationSetEntityParams,
        EvaluationSetEntity_ClassifierParams,
        EvaluationSetEntity_ExtractorParams,
        EvaluationSetEntity_SplitterParams,
    )
    from .evaluation_set_item import EvaluationSetItemParams
    from .evaluation_set_item_summary import EvaluationSetItemSummaryParams
    from .evaluation_set_run import EvaluationSetRunParams
    from .evaluation_set_run_entity import (
        EvaluationSetRunEntityParams,
        EvaluationSetRunEntity_ClassifierParams,
        EvaluationSetRunEntity_ExtractorParams,
        EvaluationSetRunEntity_SplitterParams,
    )
    from .evaluation_set_run_entity_version import (
        EvaluationSetRunEntityVersionParams,
        EvaluationSetRunEntityVersion_ClassifierVersionParams,
        EvaluationSetRunEntityVersion_ExtractorVersionParams,
        EvaluationSetRunEntityVersion_SplitterVersionParams,
    )
    from .evaluation_set_run_metrics import EvaluationSetRunMetricsParams
    from .evaluation_set_run_options import EvaluationSetRunOptionsParams
    from .excel_sheet_range import ExcelSheetRangeParams
    from .external_data_validation_result import ExternalDataValidationResultParams
    from .external_data_validation_result_response import ExternalDataValidationResultResponseParams
    from .external_data_validation_step_run import ExternalDataValidationStepRunParams
    from .external_data_validation_step_run_step import ExternalDataValidationStepRunStepParams
    from .extract_advanced_options import ExtractAdvancedOptionsParams
    from .extract_advanced_options_review_agent import ExtractAdvancedOptionsReviewAgentParams
    from .extract_chunking_options import ExtractChunkingOptionsParams
    from .extract_config import ExtractConfigParams
    from .extract_config_json import ExtractConfigJsonParams
    from .extract_config_legacy import ExtractConfigLegacyParams
    from .extract_output import ExtractOutputParams
    from .extract_output_edits import ExtractOutputEditsParams
    from .extract_output_json import ExtractOutputJsonParams
    from .extract_output_legacy import ExtractOutputLegacyParams
    from .extract_output_metadata import ExtractOutputMetadataParams
    from .extract_output_metadata_value import ExtractOutputMetadataValueParams
    from .extract_override_config_json import ExtractOverrideConfigJsonParams
    from .extract_request_extractor import ExtractRequestExtractorParams
    from .extract_request_file import ExtractRequestFileParams
    from .extract_result import ExtractResultParams
    from .extract_run import ExtractRunParams
    from .extract_run_failed_webhook_event import ExtractRunFailedWebhookEventParams
    from .extract_run_processed_webhook_event import ExtractRunProcessedWebhookEventParams
    from .extract_run_summary import ExtractRunSummaryParams
    from .extract_step_run import ExtractStepRunParams
    from .extract_step_run_step import ExtractStepRunStepParams
    from .extraction_field import ExtractionFieldParams
    from .extraction_field_result import ExtractionFieldResultParams
    from .extraction_field_result_reference import ExtractionFieldResultReferenceParams
    from .extraction_field_result_reference_bounding_boxes_item import (
        ExtractionFieldResultReferenceBoundingBoxesItemParams,
    )
    from .extractor import ExtractorParams
    from .extractor_created_webhook_event import ExtractorCreatedWebhookEventParams
    from .extractor_deleted_webhook_event import ExtractorDeletedWebhookEventParams
    from .extractor_draft_updated_webhook_event import ExtractorDraftUpdatedWebhookEventParams
    from .extractor_summary import ExtractorSummaryParams
    from .extractor_updated_webhook_event import ExtractorUpdatedWebhookEventParams
    from .extractor_version import ExtractorVersionParams
    from .extractor_version_published_webhook_event import ExtractorVersionPublishedWebhookEventParams
    from .extractor_version_summary import ExtractorVersionSummaryParams
    from .figure_details import FigureDetailsParams
    from .file import FileParams
    from .file_contents import FileContentsParams
    from .file_contents_pages_item import FileContentsPagesItemParams
    from .file_contents_sections_item import FileContentsSectionsItemParams
    from .file_contents_sheets_item import FileContentsSheetsItemParams
    from .file_from_id import FileFromIdParams
    from .file_from_text import FileFromTextParams
    from .file_from_url import FileFromUrlParams
    from .file_metadata import FileMetadataParams
    from .file_summary import FileSummaryParams
    from .insight import InsightParams
    from .legacy_batch_processor_run import LegacyBatchProcessorRunParams
    from .legacy_batch_processor_run_metrics import LegacyBatchProcessorRunMetricsParams
    from .legacy_batch_processor_run_options import LegacyBatchProcessorRunOptionsParams
    from .legacy_classification import LegacyClassificationParams
    from .legacy_classification_advanced_options import LegacyClassificationAdvancedOptionsParams
    from .legacy_classification_config import LegacyClassificationConfigParams
    from .legacy_classifier_output import LegacyClassifierOutputParams
    from .legacy_document_processor_run_credits import LegacyDocumentProcessorRunCreditsParams
    from .legacy_error import LegacyErrorParams
    from .legacy_extend_error import LegacyExtendErrorParams
    from .legacy_extract_chunking_options import LegacyExtractChunkingOptionsParams
    from .legacy_extraction_advanced_options import LegacyExtractionAdvancedOptionsParams
    from .legacy_extraction_advanced_options_review_agent import LegacyExtractionAdvancedOptionsReviewAgentParams
    from .legacy_extraction_config import LegacyExtractionConfigParams
    from .legacy_extraction_field import LegacyExtractionFieldParams
    from .legacy_extraction_field_result import LegacyExtractionFieldResultParams
    from .legacy_extraction_output import LegacyExtractionOutputParams
    from .legacy_extraction_output_edits import LegacyExtractionOutputEditsParams
    from .legacy_fields_array_output import LegacyFieldsArrayOutputParams
    from .legacy_json_output import LegacyJsonOutputParams
    from .legacy_json_output_metadata_value import LegacyJsonOutputMetadataValueParams
    from .legacy_json_output_metadata_value_citations_item import LegacyJsonOutputMetadataValueCitationsItemParams
    from .legacy_json_output_metadata_value_citations_item_polygon_item import (
        LegacyJsonOutputMetadataValueCitationsItemPolygonItemParams,
    )
    from .legacy_list_processors_processor import LegacyListProcessorsProcessorParams
    from .legacy_list_processors_processor_version import LegacyListProcessorsProcessorVersionParams
    from .legacy_list_processors_response import LegacyListProcessorsResponseParams
    from .legacy_processor import LegacyProcessorParams
    from .legacy_processor_output import LegacyProcessorOutputParams
    from .legacy_processor_run import LegacyProcessorRunParams
    from .legacy_processor_run_config import (
        LegacyProcessorRunConfigParams,
        LegacyProcessorRunConfig_ClassifyParams,
        LegacyProcessorRunConfig_ExtractParams,
        LegacyProcessorRunConfig_SplitterParams,
    )
    from .legacy_processor_run_file_input import LegacyProcessorRunFileInputParams
    from .legacy_processor_run_merged_processors_item import LegacyProcessorRunMergedProcessorsItemParams
    from .legacy_processor_run_summary import LegacyProcessorRunSummaryParams
    from .legacy_processor_version import LegacyProcessorVersionParams
    from .legacy_processor_version_config import (
        LegacyProcessorVersionConfigParams,
        LegacyProcessorVersionConfig_ClassifyParams,
        LegacyProcessorVersionConfig_ExtractParams,
        LegacyProcessorVersionConfig_SplitterParams,
    )
    from .legacy_provided_classifier_output import LegacyProvidedClassifierOutputParams
    from .legacy_provided_extraction_field_result import LegacyProvidedExtractionFieldResultParams
    from .legacy_provided_extraction_output import LegacyProvidedExtractionOutputParams
    from .legacy_provided_fields_array_output import LegacyProvidedFieldsArrayOutputParams
    from .legacy_provided_json_output import LegacyProvidedJsonOutputParams
    from .legacy_provided_processor_output import LegacyProvidedProcessorOutputParams
    from .legacy_provided_splitter_output import LegacyProvidedSplitterOutputParams
    from .legacy_provided_splitter_output_splits_item import LegacyProvidedSplitterOutputSplitsItemParams
    from .legacy_splitter_advanced_options import LegacySplitterAdvancedOptionsParams
    from .legacy_splitter_config import LegacySplitterConfigParams
    from .legacy_splitter_output import LegacySplitterOutputParams
    from .legacy_splitter_output_splits_item import LegacySplitterOutputSplitsItemParams
    from .merge_extract_result import MergeExtractResultParams
    from .merge_extract_result_merged_extractors_item import MergeExtractResultMergedExtractorsItemParams
    from .merge_extract_step_run import MergeExtractStepRunParams
    from .merge_extract_step_run_step import MergeExtractStepRunStepParams
    from .page_ranges import PageRangesParams
    from .page_ranges_item import PageRangesItemParams
    from .parent_split import ParentSplitParams
    from .parse_config import ParseConfigParams
    from .parse_config_advanced_options import ParseConfigAdvancedOptionsParams
    from .parse_config_advanced_options_return_ocr import ParseConfigAdvancedOptionsReturnOcrParams
    from .parse_config_block_options import ParseConfigBlockOptionsParams
    from .parse_config_block_options_figures import ParseConfigBlockOptionsFiguresParams
    from .parse_config_block_options_tables import ParseConfigBlockOptionsTablesParams
    from .parse_config_block_options_tables_agentic import ParseConfigBlockOptionsTablesAgenticParams
    from .parse_config_block_options_text import ParseConfigBlockOptionsTextParams
    from .parse_config_block_options_text_agentic import ParseConfigBlockOptionsTextAgenticParams
    from .parse_config_chunking_strategy import ParseConfigChunkingStrategyParams
    from .parse_config_chunking_strategy_options import ParseConfigChunkingStrategyOptionsParams
    from .parse_request_file import ParseRequestFileParams
    from .parse_result import ParseResultParams
    from .parse_run import ParseRunParams
    from .parse_run_failed_webhook_event import ParseRunFailedWebhookEventParams
    from .parse_run_metrics import ParseRunMetricsParams
    from .parse_run_output import ParseRunOutputParams
    from .parse_run_output_ocr import ParseRunOutputOcrParams
    from .parse_run_output_ocr_words_item import ParseRunOutputOcrWordsItemParams
    from .parse_run_processed_webhook_event import ParseRunProcessedWebhookEventParams
    from .parse_run_status import ParseRunStatusParams
    from .parse_step_run import ParseStepRunParams
    from .parse_step_run_step import ParseStepRunStepParams
    from .polygon import PolygonParams
    from .provided_classify_output import ProvidedClassifyOutputParams
    from .provided_extract_output import ProvidedExtractOutputParams
    from .provided_processor_output import ProvidedProcessorOutputParams
    from .provided_split_output import ProvidedSplitOutputParams
    from .provided_split_output_splits_item import ProvidedSplitOutputSplitsItemParams
    from .rule_validation_result import RuleValidationResultParams
    from .rule_validation_result_rules_item import RuleValidationResultRulesItemParams
    from .rule_validation_step_run import RuleValidationStepRunParams
    from .rule_validation_step_run_step import RuleValidationStepRunStepParams
    from .run_usage import RunUsageParams
    from .split_advanced_options import SplitAdvancedOptionsParams
    from .split_config import SplitConfigParams
    from .split_output import SplitOutputParams
    from .split_output_splits_item import SplitOutputSplitsItemParams
    from .split_override_config import SplitOverrideConfigParams
    from .split_request_file import SplitRequestFileParams
    from .split_request_splitter import SplitRequestSplitterParams
    from .split_result import SplitResultParams
    from .split_run import SplitRunParams
    from .split_run_failed_webhook_event import SplitRunFailedWebhookEventParams
    from .split_run_processed_webhook_event import SplitRunProcessedWebhookEventParams
    from .split_run_summary import SplitRunSummaryParams
    from .split_step_run import SplitStepRunParams
    from .split_step_run_step import SplitStepRunStepParams
    from .splitter import SplitterParams
    from .splitter_created_webhook_event import SplitterCreatedWebhookEventParams
    from .splitter_deleted_webhook_event import SplitterDeletedWebhookEventParams
    from .splitter_draft_updated_webhook_event import SplitterDraftUpdatedWebhookEventParams
    from .splitter_summary import SplitterSummaryParams
    from .splitter_updated_webhook_event import SplitterUpdatedWebhookEventParams
    from .splitter_version import SplitterVersionParams
    from .splitter_version_published_webhook_event import SplitterVersionPublishedWebhookEventParams
    from .splitter_version_summary import SplitterVersionSummaryParams
    from .step_run import StepRunParams
    from .step_run_base import StepRunBaseParams
    from .table_cell_details import TableCellDetailsParams
    from .table_details import TableDetailsParams
    from .too_many_requests_error_body import TooManyRequestsErrorBodyParams
    from .webhook_advanced_options import WebhookAdvancedOptionsParams
    from .webhook_endpoint import WebhookEndpointParams
    from .webhook_endpoint_create import WebhookEndpointCreateParams
    from .webhook_event import (
        WebhookEventParams,
        WebhookEvent_ClassifierCreatedParams,
        WebhookEvent_ClassifierDeletedParams,
        WebhookEvent_ClassifierDraftUpdatedParams,
        WebhookEvent_ClassifierUpdatedParams,
        WebhookEvent_ClassifierVersionPublishedParams,
        WebhookEvent_ClassifyRunFailedParams,
        WebhookEvent_ClassifyRunProcessedParams,
        WebhookEvent_EditRunFailedParams,
        WebhookEvent_EditRunProcessedParams,
        WebhookEvent_ExtractRunFailedParams,
        WebhookEvent_ExtractRunProcessedParams,
        WebhookEvent_ExtractorCreatedParams,
        WebhookEvent_ExtractorDeletedParams,
        WebhookEvent_ExtractorDraftUpdatedParams,
        WebhookEvent_ExtractorUpdatedParams,
        WebhookEvent_ExtractorVersionPublishedParams,
        WebhookEvent_ParseRunFailedParams,
        WebhookEvent_ParseRunProcessedParams,
        WebhookEvent_SplitRunFailedParams,
        WebhookEvent_SplitRunProcessedParams,
        WebhookEvent_SplitterCreatedParams,
        WebhookEvent_SplitterDeletedParams,
        WebhookEvent_SplitterDraftUpdatedParams,
        WebhookEvent_SplitterUpdatedParams,
        WebhookEvent_SplitterVersionPublishedParams,
        WebhookEvent_WorkflowCreatedParams,
        WebhookEvent_WorkflowDeletedParams,
        WebhookEvent_WorkflowDeployedParams,
        WebhookEvent_WorkflowRunCancelledParams,
        WebhookEvent_WorkflowRunCompletedParams,
        WebhookEvent_WorkflowRunFailedParams,
        WebhookEvent_WorkflowRunNeedsReviewParams,
        WebhookEvent_WorkflowRunRejectedParams,
        WebhookEvent_WorkflowRunStepRunProcessedParams,
    )
    from .webhook_payload_options import WebhookPayloadOptionsParams
    from .webhook_subscription import WebhookSubscriptionParams
    from .workflow import WorkflowParams
    from .workflow_created_webhook_event import WorkflowCreatedWebhookEventParams
    from .workflow_deleted_webhook_event import WorkflowDeletedWebhookEventParams
    from .workflow_deployed_webhook_event import WorkflowDeployedWebhookEventParams
    from .workflow_reference import WorkflowReferenceParams
    from .workflow_run import WorkflowRunParams
    from .workflow_run_cancelled_webhook_event import WorkflowRunCancelledWebhookEventParams
    from .workflow_run_completed_webhook_event import WorkflowRunCompletedWebhookEventParams
    from .workflow_run_failed_webhook_event import WorkflowRunFailedWebhookEventParams
    from .workflow_run_needs_review_webhook_event import WorkflowRunNeedsReviewWebhookEventParams
    from .workflow_run_rejected_webhook_event import WorkflowRunRejectedWebhookEventParams
    from .workflow_run_step_run_processed_webhook_event import WorkflowRunStepRunProcessedWebhookEventParams
    from .workflow_run_summary import WorkflowRunSummaryParams
    from .workflow_step_base import WorkflowStepBaseParams
    from .workflow_summary import WorkflowSummaryParams
    from .workflow_version import WorkflowVersionParams
    from .workflow_version_summary import WorkflowVersionSummaryParams
_dynamic_imports: typing.Dict[str, str] = {
    "ApiErrorParams": ".api_error",
    "ArrayStrategyParams": ".array_strategy",
    "BatchProcessorRunMetricsParams": ".batch_processor_run_metrics",
    "BatchProcessorRunOptionsParams": ".batch_processor_run_options",
    "BatchProcessorRunParams": ".batch_processor_run",
    "BatchRunEntityParams": ".batch_run_entity",
    "BatchRunEntityVersionParams": ".batch_run_entity_version",
    "BatchRunEntityVersion_ClassifierVersionParams": ".batch_run_entity_version",
    "BatchRunEntityVersion_ExtractorVersionParams": ".batch_run_entity_version",
    "BatchRunEntityVersion_SplitterVersionParams": ".batch_run_entity_version",
    "BatchRunEntity_ClassifierParams": ".batch_run_entity",
    "BatchRunEntity_ExtractorParams": ".batch_run_entity",
    "BatchRunEntity_SplitterParams": ".batch_run_entity",
    "BatchRunMetricsParams": ".batch_run_metrics",
    "BatchRunParams": ".batch_run",
    "BlockDetailsParams": ".block_details",
    "BlockMetadataPageParams": ".block_metadata_page",
    "BlockMetadataParams": ".block_metadata",
    "BlockParams": ".block",
    "BlockPolygonItemParams": ".block_polygon_item",
    "BoundingBoxParams": ".bounding_box",
    "ChunkMetadataPageRangeParams": ".chunk_metadata_page_range",
    "ChunkMetadataParams": ".chunk_metadata",
    "ChunkParams": ".chunk",
    "CitationPageParams": ".citation_page",
    "CitationParams": ".citation",
    "ClassificationParams": ".classification",
    "ClassificationsParams": ".classifications",
    "ClassifierCreatedWebhookEventParams": ".classifier_created_webhook_event",
    "ClassifierDeletedWebhookEventParams": ".classifier_deleted_webhook_event",
    "ClassifierDraftUpdatedWebhookEventParams": ".classifier_draft_updated_webhook_event",
    "ClassifierParams": ".classifier",
    "ClassifierSummaryParams": ".classifier_summary",
    "ClassifierUpdatedWebhookEventParams": ".classifier_updated_webhook_event",
    "ClassifierVersionParams": ".classifier_version",
    "ClassifierVersionPublishedWebhookEventParams": ".classifier_version_published_webhook_event",
    "ClassifierVersionSummaryParams": ".classifier_version_summary",
    "ClassifyAdvancedOptionsParams": ".classify_advanced_options",
    "ClassifyConfigParams": ".classify_config",
    "ClassifyOutputParams": ".classify_output",
    "ClassifyOverrideConfigParams": ".classify_override_config",
    "ClassifyRequestClassifierParams": ".classify_request_classifier",
    "ClassifyRequestFileParams": ".classify_request_file",
    "ClassifyResultParams": ".classify_result",
    "ClassifyRunFailedWebhookEventParams": ".classify_run_failed_webhook_event",
    "ClassifyRunParams": ".classify_run",
    "ClassifyRunProcessedWebhookEventParams": ".classify_run_processed_webhook_event",
    "ClassifyRunSummaryParams": ".classify_run_summary",
    "ClassifyStepRunParams": ".classify_step_run",
    "ClassifyStepRunStepParams": ".classify_step_run_step",
    "ConditionalExtractResultParams": ".conditional_extract_result",
    "ConditionalExtractStepRunParams": ".conditional_extract_step_run",
    "ConditionalExtractStepRunStepParams": ".conditional_extract_step_run_step",
    "EditBoundingBoxParams": ".edit_bounding_box",
    "EditConfigAdvancedOptionsParams": ".edit_config_advanced_options",
    "EditConfigParams": ".edit_config",
    "EditJsonParams": ".edit_json",
    "EditObjectJsonParams": ".edit_object_json",
    "EditRequestFileParams": ".edit_request_file",
    "EditRootJsonParams": ".edit_root_json",
    "EditRunFailedWebhookEventParams": ".edit_run_failed_webhook_event",
    "EditRunMetricsParams": ".edit_run_metrics",
    "EditRunOutputEditedFileParams": ".edit_run_output_edited_file",
    "EditRunOutputParams": ".edit_run_output",
    "EditRunParams": ".edit_run",
    "EditRunProcessedWebhookEventParams": ".edit_run_processed_webhook_event",
    "EditTextOptionsParams": ".edit_text_options",
    "EnumOptionParams": ".enum_option",
    "EnumParams": ".enum",
    "EvaluationSetEntityParams": ".evaluation_set_entity",
    "EvaluationSetEntity_ClassifierParams": ".evaluation_set_entity",
    "EvaluationSetEntity_ExtractorParams": ".evaluation_set_entity",
    "EvaluationSetEntity_SplitterParams": ".evaluation_set_entity",
    "EvaluationSetItemParams": ".evaluation_set_item",
    "EvaluationSetItemSummaryParams": ".evaluation_set_item_summary",
    "EvaluationSetParams": ".evaluation_set",
    "EvaluationSetRunEntityParams": ".evaluation_set_run_entity",
    "EvaluationSetRunEntityVersionParams": ".evaluation_set_run_entity_version",
    "EvaluationSetRunEntityVersion_ClassifierVersionParams": ".evaluation_set_run_entity_version",
    "EvaluationSetRunEntityVersion_ExtractorVersionParams": ".evaluation_set_run_entity_version",
    "EvaluationSetRunEntityVersion_SplitterVersionParams": ".evaluation_set_run_entity_version",
    "EvaluationSetRunEntity_ClassifierParams": ".evaluation_set_run_entity",
    "EvaluationSetRunEntity_ExtractorParams": ".evaluation_set_run_entity",
    "EvaluationSetRunEntity_SplitterParams": ".evaluation_set_run_entity",
    "EvaluationSetRunMetricsParams": ".evaluation_set_run_metrics",
    "EvaluationSetRunOptionsParams": ".evaluation_set_run_options",
    "EvaluationSetRunParams": ".evaluation_set_run",
    "ExcelSheetRangeParams": ".excel_sheet_range",
    "ExternalDataValidationResultParams": ".external_data_validation_result",
    "ExternalDataValidationResultResponseParams": ".external_data_validation_result_response",
    "ExternalDataValidationStepRunParams": ".external_data_validation_step_run",
    "ExternalDataValidationStepRunStepParams": ".external_data_validation_step_run_step",
    "ExtractAdvancedOptionsParams": ".extract_advanced_options",
    "ExtractAdvancedOptionsReviewAgentParams": ".extract_advanced_options_review_agent",
    "ExtractChunkingOptionsParams": ".extract_chunking_options",
    "ExtractConfigJsonParams": ".extract_config_json",
    "ExtractConfigLegacyParams": ".extract_config_legacy",
    "ExtractConfigParams": ".extract_config",
    "ExtractOutputEditsParams": ".extract_output_edits",
    "ExtractOutputJsonParams": ".extract_output_json",
    "ExtractOutputLegacyParams": ".extract_output_legacy",
    "ExtractOutputMetadataParams": ".extract_output_metadata",
    "ExtractOutputMetadataValueParams": ".extract_output_metadata_value",
    "ExtractOutputParams": ".extract_output",
    "ExtractOverrideConfigJsonParams": ".extract_override_config_json",
    "ExtractRequestExtractorParams": ".extract_request_extractor",
    "ExtractRequestFileParams": ".extract_request_file",
    "ExtractResultParams": ".extract_result",
    "ExtractRunFailedWebhookEventParams": ".extract_run_failed_webhook_event",
    "ExtractRunParams": ".extract_run",
    "ExtractRunProcessedWebhookEventParams": ".extract_run_processed_webhook_event",
    "ExtractRunSummaryParams": ".extract_run_summary",
    "ExtractStepRunParams": ".extract_step_run",
    "ExtractStepRunStepParams": ".extract_step_run_step",
    "ExtractionFieldParams": ".extraction_field",
    "ExtractionFieldResultParams": ".extraction_field_result",
    "ExtractionFieldResultReferenceBoundingBoxesItemParams": ".extraction_field_result_reference_bounding_boxes_item",
    "ExtractionFieldResultReferenceParams": ".extraction_field_result_reference",
    "ExtractorCreatedWebhookEventParams": ".extractor_created_webhook_event",
    "ExtractorDeletedWebhookEventParams": ".extractor_deleted_webhook_event",
    "ExtractorDraftUpdatedWebhookEventParams": ".extractor_draft_updated_webhook_event",
    "ExtractorParams": ".extractor",
    "ExtractorSummaryParams": ".extractor_summary",
    "ExtractorUpdatedWebhookEventParams": ".extractor_updated_webhook_event",
    "ExtractorVersionParams": ".extractor_version",
    "ExtractorVersionPublishedWebhookEventParams": ".extractor_version_published_webhook_event",
    "ExtractorVersionSummaryParams": ".extractor_version_summary",
    "FigureDetailsParams": ".figure_details",
    "FileContentsPagesItemParams": ".file_contents_pages_item",
    "FileContentsParams": ".file_contents",
    "FileContentsSectionsItemParams": ".file_contents_sections_item",
    "FileContentsSheetsItemParams": ".file_contents_sheets_item",
    "FileFromIdParams": ".file_from_id",
    "FileFromTextParams": ".file_from_text",
    "FileFromUrlParams": ".file_from_url",
    "FileMetadataParams": ".file_metadata",
    "FileParams": ".file",
    "FileSummaryParams": ".file_summary",
    "InsightParams": ".insight",
    "LegacyBatchProcessorRunMetricsParams": ".legacy_batch_processor_run_metrics",
    "LegacyBatchProcessorRunOptionsParams": ".legacy_batch_processor_run_options",
    "LegacyBatchProcessorRunParams": ".legacy_batch_processor_run",
    "LegacyClassificationAdvancedOptionsParams": ".legacy_classification_advanced_options",
    "LegacyClassificationConfigParams": ".legacy_classification_config",
    "LegacyClassificationParams": ".legacy_classification",
    "LegacyClassifierOutputParams": ".legacy_classifier_output",
    "LegacyDocumentProcessorRunCreditsParams": ".legacy_document_processor_run_credits",
    "LegacyErrorParams": ".legacy_error",
    "LegacyExtendErrorParams": ".legacy_extend_error",
    "LegacyExtractChunkingOptionsParams": ".legacy_extract_chunking_options",
    "LegacyExtractionAdvancedOptionsParams": ".legacy_extraction_advanced_options",
    "LegacyExtractionAdvancedOptionsReviewAgentParams": ".legacy_extraction_advanced_options_review_agent",
    "LegacyExtractionConfigParams": ".legacy_extraction_config",
    "LegacyExtractionFieldParams": ".legacy_extraction_field",
    "LegacyExtractionFieldResultParams": ".legacy_extraction_field_result",
    "LegacyExtractionOutputEditsParams": ".legacy_extraction_output_edits",
    "LegacyExtractionOutputParams": ".legacy_extraction_output",
    "LegacyFieldsArrayOutputParams": ".legacy_fields_array_output",
    "LegacyJsonOutputMetadataValueCitationsItemParams": ".legacy_json_output_metadata_value_citations_item",
    "LegacyJsonOutputMetadataValueCitationsItemPolygonItemParams": ".legacy_json_output_metadata_value_citations_item_polygon_item",
    "LegacyJsonOutputMetadataValueParams": ".legacy_json_output_metadata_value",
    "LegacyJsonOutputParams": ".legacy_json_output",
    "LegacyListProcessorsProcessorParams": ".legacy_list_processors_processor",
    "LegacyListProcessorsProcessorVersionParams": ".legacy_list_processors_processor_version",
    "LegacyListProcessorsResponseParams": ".legacy_list_processors_response",
    "LegacyProcessorOutputParams": ".legacy_processor_output",
    "LegacyProcessorParams": ".legacy_processor",
    "LegacyProcessorRunConfigParams": ".legacy_processor_run_config",
    "LegacyProcessorRunConfig_ClassifyParams": ".legacy_processor_run_config",
    "LegacyProcessorRunConfig_ExtractParams": ".legacy_processor_run_config",
    "LegacyProcessorRunConfig_SplitterParams": ".legacy_processor_run_config",
    "LegacyProcessorRunFileInputParams": ".legacy_processor_run_file_input",
    "LegacyProcessorRunMergedProcessorsItemParams": ".legacy_processor_run_merged_processors_item",
    "LegacyProcessorRunParams": ".legacy_processor_run",
    "LegacyProcessorRunSummaryParams": ".legacy_processor_run_summary",
    "LegacyProcessorVersionConfigParams": ".legacy_processor_version_config",
    "LegacyProcessorVersionConfig_ClassifyParams": ".legacy_processor_version_config",
    "LegacyProcessorVersionConfig_ExtractParams": ".legacy_processor_version_config",
    "LegacyProcessorVersionConfig_SplitterParams": ".legacy_processor_version_config",
    "LegacyProcessorVersionParams": ".legacy_processor_version",
    "LegacyProvidedClassifierOutputParams": ".legacy_provided_classifier_output",
    "LegacyProvidedExtractionFieldResultParams": ".legacy_provided_extraction_field_result",
    "LegacyProvidedExtractionOutputParams": ".legacy_provided_extraction_output",
    "LegacyProvidedFieldsArrayOutputParams": ".legacy_provided_fields_array_output",
    "LegacyProvidedJsonOutputParams": ".legacy_provided_json_output",
    "LegacyProvidedProcessorOutputParams": ".legacy_provided_processor_output",
    "LegacyProvidedSplitterOutputParams": ".legacy_provided_splitter_output",
    "LegacyProvidedSplitterOutputSplitsItemParams": ".legacy_provided_splitter_output_splits_item",
    "LegacySplitterAdvancedOptionsParams": ".legacy_splitter_advanced_options",
    "LegacySplitterConfigParams": ".legacy_splitter_config",
    "LegacySplitterOutputParams": ".legacy_splitter_output",
    "LegacySplitterOutputSplitsItemParams": ".legacy_splitter_output_splits_item",
    "MergeExtractResultMergedExtractorsItemParams": ".merge_extract_result_merged_extractors_item",
    "MergeExtractResultParams": ".merge_extract_result",
    "MergeExtractStepRunParams": ".merge_extract_step_run",
    "MergeExtractStepRunStepParams": ".merge_extract_step_run_step",
    "PageRangesItemParams": ".page_ranges_item",
    "PageRangesParams": ".page_ranges",
    "ParentSplitParams": ".parent_split",
    "ParseConfigAdvancedOptionsParams": ".parse_config_advanced_options",
    "ParseConfigAdvancedOptionsReturnOcrParams": ".parse_config_advanced_options_return_ocr",
    "ParseConfigBlockOptionsFiguresParams": ".parse_config_block_options_figures",
    "ParseConfigBlockOptionsParams": ".parse_config_block_options",
    "ParseConfigBlockOptionsTablesAgenticParams": ".parse_config_block_options_tables_agentic",
    "ParseConfigBlockOptionsTablesParams": ".parse_config_block_options_tables",
    "ParseConfigBlockOptionsTextAgenticParams": ".parse_config_block_options_text_agentic",
    "ParseConfigBlockOptionsTextParams": ".parse_config_block_options_text",
    "ParseConfigChunkingStrategyOptionsParams": ".parse_config_chunking_strategy_options",
    "ParseConfigChunkingStrategyParams": ".parse_config_chunking_strategy",
    "ParseConfigParams": ".parse_config",
    "ParseRequestFileParams": ".parse_request_file",
    "ParseResultParams": ".parse_result",
    "ParseRunFailedWebhookEventParams": ".parse_run_failed_webhook_event",
    "ParseRunMetricsParams": ".parse_run_metrics",
    "ParseRunOutputOcrParams": ".parse_run_output_ocr",
    "ParseRunOutputOcrWordsItemParams": ".parse_run_output_ocr_words_item",
    "ParseRunOutputParams": ".parse_run_output",
    "ParseRunParams": ".parse_run",
    "ParseRunProcessedWebhookEventParams": ".parse_run_processed_webhook_event",
    "ParseRunStatusParams": ".parse_run_status",
    "ParseStepRunParams": ".parse_step_run",
    "ParseStepRunStepParams": ".parse_step_run_step",
    "PolygonParams": ".polygon",
    "ProvidedClassifyOutputParams": ".provided_classify_output",
    "ProvidedExtractOutputParams": ".provided_extract_output",
    "ProvidedProcessorOutputParams": ".provided_processor_output",
    "ProvidedSplitOutputParams": ".provided_split_output",
    "ProvidedSplitOutputSplitsItemParams": ".provided_split_output_splits_item",
    "RuleValidationResultParams": ".rule_validation_result",
    "RuleValidationResultRulesItemParams": ".rule_validation_result_rules_item",
    "RuleValidationStepRunParams": ".rule_validation_step_run",
    "RuleValidationStepRunStepParams": ".rule_validation_step_run_step",
    "RunUsageParams": ".run_usage",
    "SplitAdvancedOptionsParams": ".split_advanced_options",
    "SplitConfigParams": ".split_config",
    "SplitOutputParams": ".split_output",
    "SplitOutputSplitsItemParams": ".split_output_splits_item",
    "SplitOverrideConfigParams": ".split_override_config",
    "SplitRequestFileParams": ".split_request_file",
    "SplitRequestSplitterParams": ".split_request_splitter",
    "SplitResultParams": ".split_result",
    "SplitRunFailedWebhookEventParams": ".split_run_failed_webhook_event",
    "SplitRunParams": ".split_run",
    "SplitRunProcessedWebhookEventParams": ".split_run_processed_webhook_event",
    "SplitRunSummaryParams": ".split_run_summary",
    "SplitStepRunParams": ".split_step_run",
    "SplitStepRunStepParams": ".split_step_run_step",
    "SplitterCreatedWebhookEventParams": ".splitter_created_webhook_event",
    "SplitterDeletedWebhookEventParams": ".splitter_deleted_webhook_event",
    "SplitterDraftUpdatedWebhookEventParams": ".splitter_draft_updated_webhook_event",
    "SplitterParams": ".splitter",
    "SplitterSummaryParams": ".splitter_summary",
    "SplitterUpdatedWebhookEventParams": ".splitter_updated_webhook_event",
    "SplitterVersionParams": ".splitter_version",
    "SplitterVersionPublishedWebhookEventParams": ".splitter_version_published_webhook_event",
    "SplitterVersionSummaryParams": ".splitter_version_summary",
    "StepRunBaseParams": ".step_run_base",
    "StepRunParams": ".step_run",
    "TableCellDetailsParams": ".table_cell_details",
    "TableDetailsParams": ".table_details",
    "TooManyRequestsErrorBodyParams": ".too_many_requests_error_body",
    "WebhookAdvancedOptionsParams": ".webhook_advanced_options",
    "WebhookEndpointCreateParams": ".webhook_endpoint_create",
    "WebhookEndpointParams": ".webhook_endpoint",
    "WebhookEventParams": ".webhook_event",
    "WebhookEvent_ClassifierCreatedParams": ".webhook_event",
    "WebhookEvent_ClassifierDeletedParams": ".webhook_event",
    "WebhookEvent_ClassifierDraftUpdatedParams": ".webhook_event",
    "WebhookEvent_ClassifierUpdatedParams": ".webhook_event",
    "WebhookEvent_ClassifierVersionPublishedParams": ".webhook_event",
    "WebhookEvent_ClassifyRunFailedParams": ".webhook_event",
    "WebhookEvent_ClassifyRunProcessedParams": ".webhook_event",
    "WebhookEvent_EditRunFailedParams": ".webhook_event",
    "WebhookEvent_EditRunProcessedParams": ".webhook_event",
    "WebhookEvent_ExtractRunFailedParams": ".webhook_event",
    "WebhookEvent_ExtractRunProcessedParams": ".webhook_event",
    "WebhookEvent_ExtractorCreatedParams": ".webhook_event",
    "WebhookEvent_ExtractorDeletedParams": ".webhook_event",
    "WebhookEvent_ExtractorDraftUpdatedParams": ".webhook_event",
    "WebhookEvent_ExtractorUpdatedParams": ".webhook_event",
    "WebhookEvent_ExtractorVersionPublishedParams": ".webhook_event",
    "WebhookEvent_ParseRunFailedParams": ".webhook_event",
    "WebhookEvent_ParseRunProcessedParams": ".webhook_event",
    "WebhookEvent_SplitRunFailedParams": ".webhook_event",
    "WebhookEvent_SplitRunProcessedParams": ".webhook_event",
    "WebhookEvent_SplitterCreatedParams": ".webhook_event",
    "WebhookEvent_SplitterDeletedParams": ".webhook_event",
    "WebhookEvent_SplitterDraftUpdatedParams": ".webhook_event",
    "WebhookEvent_SplitterUpdatedParams": ".webhook_event",
    "WebhookEvent_SplitterVersionPublishedParams": ".webhook_event",
    "WebhookEvent_WorkflowCreatedParams": ".webhook_event",
    "WebhookEvent_WorkflowDeletedParams": ".webhook_event",
    "WebhookEvent_WorkflowDeployedParams": ".webhook_event",
    "WebhookEvent_WorkflowRunCancelledParams": ".webhook_event",
    "WebhookEvent_WorkflowRunCompletedParams": ".webhook_event",
    "WebhookEvent_WorkflowRunFailedParams": ".webhook_event",
    "WebhookEvent_WorkflowRunNeedsReviewParams": ".webhook_event",
    "WebhookEvent_WorkflowRunRejectedParams": ".webhook_event",
    "WebhookEvent_WorkflowRunStepRunProcessedParams": ".webhook_event",
    "WebhookPayloadOptionsParams": ".webhook_payload_options",
    "WebhookSubscriptionParams": ".webhook_subscription",
    "WorkflowCreatedWebhookEventParams": ".workflow_created_webhook_event",
    "WorkflowDeletedWebhookEventParams": ".workflow_deleted_webhook_event",
    "WorkflowDeployedWebhookEventParams": ".workflow_deployed_webhook_event",
    "WorkflowParams": ".workflow",
    "WorkflowReferenceParams": ".workflow_reference",
    "WorkflowRunCancelledWebhookEventParams": ".workflow_run_cancelled_webhook_event",
    "WorkflowRunCompletedWebhookEventParams": ".workflow_run_completed_webhook_event",
    "WorkflowRunFailedWebhookEventParams": ".workflow_run_failed_webhook_event",
    "WorkflowRunNeedsReviewWebhookEventParams": ".workflow_run_needs_review_webhook_event",
    "WorkflowRunParams": ".workflow_run",
    "WorkflowRunRejectedWebhookEventParams": ".workflow_run_rejected_webhook_event",
    "WorkflowRunStepRunProcessedWebhookEventParams": ".workflow_run_step_run_processed_webhook_event",
    "WorkflowRunSummaryParams": ".workflow_run_summary",
    "WorkflowStepBaseParams": ".workflow_step_base",
    "WorkflowSummaryParams": ".workflow_summary",
    "WorkflowVersionParams": ".workflow_version",
    "WorkflowVersionSummaryParams": ".workflow_version_summary",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "ApiErrorParams",
    "ArrayStrategyParams",
    "BatchProcessorRunMetricsParams",
    "BatchProcessorRunOptionsParams",
    "BatchProcessorRunParams",
    "BatchRunEntityParams",
    "BatchRunEntityVersionParams",
    "BatchRunEntityVersion_ClassifierVersionParams",
    "BatchRunEntityVersion_ExtractorVersionParams",
    "BatchRunEntityVersion_SplitterVersionParams",
    "BatchRunEntity_ClassifierParams",
    "BatchRunEntity_ExtractorParams",
    "BatchRunEntity_SplitterParams",
    "BatchRunMetricsParams",
    "BatchRunParams",
    "BlockDetailsParams",
    "BlockMetadataPageParams",
    "BlockMetadataParams",
    "BlockParams",
    "BlockPolygonItemParams",
    "BoundingBoxParams",
    "ChunkMetadataPageRangeParams",
    "ChunkMetadataParams",
    "ChunkParams",
    "CitationPageParams",
    "CitationParams",
    "ClassificationParams",
    "ClassificationsParams",
    "ClassifierCreatedWebhookEventParams",
    "ClassifierDeletedWebhookEventParams",
    "ClassifierDraftUpdatedWebhookEventParams",
    "ClassifierParams",
    "ClassifierSummaryParams",
    "ClassifierUpdatedWebhookEventParams",
    "ClassifierVersionParams",
    "ClassifierVersionPublishedWebhookEventParams",
    "ClassifierVersionSummaryParams",
    "ClassifyAdvancedOptionsParams",
    "ClassifyConfigParams",
    "ClassifyOutputParams",
    "ClassifyOverrideConfigParams",
    "ClassifyRequestClassifierParams",
    "ClassifyRequestFileParams",
    "ClassifyResultParams",
    "ClassifyRunFailedWebhookEventParams",
    "ClassifyRunParams",
    "ClassifyRunProcessedWebhookEventParams",
    "ClassifyRunSummaryParams",
    "ClassifyStepRunParams",
    "ClassifyStepRunStepParams",
    "ConditionalExtractResultParams",
    "ConditionalExtractStepRunParams",
    "ConditionalExtractStepRunStepParams",
    "EditBoundingBoxParams",
    "EditConfigAdvancedOptionsParams",
    "EditConfigParams",
    "EditJsonParams",
    "EditObjectJsonParams",
    "EditRequestFileParams",
    "EditRootJsonParams",
    "EditRunFailedWebhookEventParams",
    "EditRunMetricsParams",
    "EditRunOutputEditedFileParams",
    "EditRunOutputParams",
    "EditRunParams",
    "EditRunProcessedWebhookEventParams",
    "EditTextOptionsParams",
    "EnumOptionParams",
    "EnumParams",
    "EvaluationSetEntityParams",
    "EvaluationSetEntity_ClassifierParams",
    "EvaluationSetEntity_ExtractorParams",
    "EvaluationSetEntity_SplitterParams",
    "EvaluationSetItemParams",
    "EvaluationSetItemSummaryParams",
    "EvaluationSetParams",
    "EvaluationSetRunEntityParams",
    "EvaluationSetRunEntityVersionParams",
    "EvaluationSetRunEntityVersion_ClassifierVersionParams",
    "EvaluationSetRunEntityVersion_ExtractorVersionParams",
    "EvaluationSetRunEntityVersion_SplitterVersionParams",
    "EvaluationSetRunEntity_ClassifierParams",
    "EvaluationSetRunEntity_ExtractorParams",
    "EvaluationSetRunEntity_SplitterParams",
    "EvaluationSetRunMetricsParams",
    "EvaluationSetRunOptionsParams",
    "EvaluationSetRunParams",
    "ExcelSheetRangeParams",
    "ExternalDataValidationResultParams",
    "ExternalDataValidationResultResponseParams",
    "ExternalDataValidationStepRunParams",
    "ExternalDataValidationStepRunStepParams",
    "ExtractAdvancedOptionsParams",
    "ExtractAdvancedOptionsReviewAgentParams",
    "ExtractChunkingOptionsParams",
    "ExtractConfigJsonParams",
    "ExtractConfigLegacyParams",
    "ExtractConfigParams",
    "ExtractOutputEditsParams",
    "ExtractOutputJsonParams",
    "ExtractOutputLegacyParams",
    "ExtractOutputMetadataParams",
    "ExtractOutputMetadataValueParams",
    "ExtractOutputParams",
    "ExtractOverrideConfigJsonParams",
    "ExtractRequestExtractorParams",
    "ExtractRequestFileParams",
    "ExtractResultParams",
    "ExtractRunFailedWebhookEventParams",
    "ExtractRunParams",
    "ExtractRunProcessedWebhookEventParams",
    "ExtractRunSummaryParams",
    "ExtractStepRunParams",
    "ExtractStepRunStepParams",
    "ExtractionFieldParams",
    "ExtractionFieldResultParams",
    "ExtractionFieldResultReferenceBoundingBoxesItemParams",
    "ExtractionFieldResultReferenceParams",
    "ExtractorCreatedWebhookEventParams",
    "ExtractorDeletedWebhookEventParams",
    "ExtractorDraftUpdatedWebhookEventParams",
    "ExtractorParams",
    "ExtractorSummaryParams",
    "ExtractorUpdatedWebhookEventParams",
    "ExtractorVersionParams",
    "ExtractorVersionPublishedWebhookEventParams",
    "ExtractorVersionSummaryParams",
    "FigureDetailsParams",
    "FileContentsPagesItemParams",
    "FileContentsParams",
    "FileContentsSectionsItemParams",
    "FileContentsSheetsItemParams",
    "FileFromIdParams",
    "FileFromTextParams",
    "FileFromUrlParams",
    "FileMetadataParams",
    "FileParams",
    "FileSummaryParams",
    "InsightParams",
    "LegacyBatchProcessorRunMetricsParams",
    "LegacyBatchProcessorRunOptionsParams",
    "LegacyBatchProcessorRunParams",
    "LegacyClassificationAdvancedOptionsParams",
    "LegacyClassificationConfigParams",
    "LegacyClassificationParams",
    "LegacyClassifierOutputParams",
    "LegacyDocumentProcessorRunCreditsParams",
    "LegacyErrorParams",
    "LegacyExtendErrorParams",
    "LegacyExtractChunkingOptionsParams",
    "LegacyExtractionAdvancedOptionsParams",
    "LegacyExtractionAdvancedOptionsReviewAgentParams",
    "LegacyExtractionConfigParams",
    "LegacyExtractionFieldParams",
    "LegacyExtractionFieldResultParams",
    "LegacyExtractionOutputEditsParams",
    "LegacyExtractionOutputParams",
    "LegacyFieldsArrayOutputParams",
    "LegacyJsonOutputMetadataValueCitationsItemParams",
    "LegacyJsonOutputMetadataValueCitationsItemPolygonItemParams",
    "LegacyJsonOutputMetadataValueParams",
    "LegacyJsonOutputParams",
    "LegacyListProcessorsProcessorParams",
    "LegacyListProcessorsProcessorVersionParams",
    "LegacyListProcessorsResponseParams",
    "LegacyProcessorOutputParams",
    "LegacyProcessorParams",
    "LegacyProcessorRunConfigParams",
    "LegacyProcessorRunConfig_ClassifyParams",
    "LegacyProcessorRunConfig_ExtractParams",
    "LegacyProcessorRunConfig_SplitterParams",
    "LegacyProcessorRunFileInputParams",
    "LegacyProcessorRunMergedProcessorsItemParams",
    "LegacyProcessorRunParams",
    "LegacyProcessorRunSummaryParams",
    "LegacyProcessorVersionConfigParams",
    "LegacyProcessorVersionConfig_ClassifyParams",
    "LegacyProcessorVersionConfig_ExtractParams",
    "LegacyProcessorVersionConfig_SplitterParams",
    "LegacyProcessorVersionParams",
    "LegacyProvidedClassifierOutputParams",
    "LegacyProvidedExtractionFieldResultParams",
    "LegacyProvidedExtractionOutputParams",
    "LegacyProvidedFieldsArrayOutputParams",
    "LegacyProvidedJsonOutputParams",
    "LegacyProvidedProcessorOutputParams",
    "LegacyProvidedSplitterOutputParams",
    "LegacyProvidedSplitterOutputSplitsItemParams",
    "LegacySplitterAdvancedOptionsParams",
    "LegacySplitterConfigParams",
    "LegacySplitterOutputParams",
    "LegacySplitterOutputSplitsItemParams",
    "MergeExtractResultMergedExtractorsItemParams",
    "MergeExtractResultParams",
    "MergeExtractStepRunParams",
    "MergeExtractStepRunStepParams",
    "PageRangesItemParams",
    "PageRangesParams",
    "ParentSplitParams",
    "ParseConfigAdvancedOptionsParams",
    "ParseConfigAdvancedOptionsReturnOcrParams",
    "ParseConfigBlockOptionsFiguresParams",
    "ParseConfigBlockOptionsParams",
    "ParseConfigBlockOptionsTablesAgenticParams",
    "ParseConfigBlockOptionsTablesParams",
    "ParseConfigBlockOptionsTextAgenticParams",
    "ParseConfigBlockOptionsTextParams",
    "ParseConfigChunkingStrategyOptionsParams",
    "ParseConfigChunkingStrategyParams",
    "ParseConfigParams",
    "ParseRequestFileParams",
    "ParseResultParams",
    "ParseRunFailedWebhookEventParams",
    "ParseRunMetricsParams",
    "ParseRunOutputOcrParams",
    "ParseRunOutputOcrWordsItemParams",
    "ParseRunOutputParams",
    "ParseRunParams",
    "ParseRunProcessedWebhookEventParams",
    "ParseRunStatusParams",
    "ParseStepRunParams",
    "ParseStepRunStepParams",
    "PolygonParams",
    "ProvidedClassifyOutputParams",
    "ProvidedExtractOutputParams",
    "ProvidedProcessorOutputParams",
    "ProvidedSplitOutputParams",
    "ProvidedSplitOutputSplitsItemParams",
    "RuleValidationResultParams",
    "RuleValidationResultRulesItemParams",
    "RuleValidationStepRunParams",
    "RuleValidationStepRunStepParams",
    "RunUsageParams",
    "SplitAdvancedOptionsParams",
    "SplitConfigParams",
    "SplitOutputParams",
    "SplitOutputSplitsItemParams",
    "SplitOverrideConfigParams",
    "SplitRequestFileParams",
    "SplitRequestSplitterParams",
    "SplitResultParams",
    "SplitRunFailedWebhookEventParams",
    "SplitRunParams",
    "SplitRunProcessedWebhookEventParams",
    "SplitRunSummaryParams",
    "SplitStepRunParams",
    "SplitStepRunStepParams",
    "SplitterCreatedWebhookEventParams",
    "SplitterDeletedWebhookEventParams",
    "SplitterDraftUpdatedWebhookEventParams",
    "SplitterParams",
    "SplitterSummaryParams",
    "SplitterUpdatedWebhookEventParams",
    "SplitterVersionParams",
    "SplitterVersionPublishedWebhookEventParams",
    "SplitterVersionSummaryParams",
    "StepRunBaseParams",
    "StepRunParams",
    "TableCellDetailsParams",
    "TableDetailsParams",
    "TooManyRequestsErrorBodyParams",
    "WebhookAdvancedOptionsParams",
    "WebhookEndpointCreateParams",
    "WebhookEndpointParams",
    "WebhookEventParams",
    "WebhookEvent_ClassifierCreatedParams",
    "WebhookEvent_ClassifierDeletedParams",
    "WebhookEvent_ClassifierDraftUpdatedParams",
    "WebhookEvent_ClassifierUpdatedParams",
    "WebhookEvent_ClassifierVersionPublishedParams",
    "WebhookEvent_ClassifyRunFailedParams",
    "WebhookEvent_ClassifyRunProcessedParams",
    "WebhookEvent_EditRunFailedParams",
    "WebhookEvent_EditRunProcessedParams",
    "WebhookEvent_ExtractRunFailedParams",
    "WebhookEvent_ExtractRunProcessedParams",
    "WebhookEvent_ExtractorCreatedParams",
    "WebhookEvent_ExtractorDeletedParams",
    "WebhookEvent_ExtractorDraftUpdatedParams",
    "WebhookEvent_ExtractorUpdatedParams",
    "WebhookEvent_ExtractorVersionPublishedParams",
    "WebhookEvent_ParseRunFailedParams",
    "WebhookEvent_ParseRunProcessedParams",
    "WebhookEvent_SplitRunFailedParams",
    "WebhookEvent_SplitRunProcessedParams",
    "WebhookEvent_SplitterCreatedParams",
    "WebhookEvent_SplitterDeletedParams",
    "WebhookEvent_SplitterDraftUpdatedParams",
    "WebhookEvent_SplitterUpdatedParams",
    "WebhookEvent_SplitterVersionPublishedParams",
    "WebhookEvent_WorkflowCreatedParams",
    "WebhookEvent_WorkflowDeletedParams",
    "WebhookEvent_WorkflowDeployedParams",
    "WebhookEvent_WorkflowRunCancelledParams",
    "WebhookEvent_WorkflowRunCompletedParams",
    "WebhookEvent_WorkflowRunFailedParams",
    "WebhookEvent_WorkflowRunNeedsReviewParams",
    "WebhookEvent_WorkflowRunRejectedParams",
    "WebhookEvent_WorkflowRunStepRunProcessedParams",
    "WebhookPayloadOptionsParams",
    "WebhookSubscriptionParams",
    "WorkflowCreatedWebhookEventParams",
    "WorkflowDeletedWebhookEventParams",
    "WorkflowDeployedWebhookEventParams",
    "WorkflowParams",
    "WorkflowReferenceParams",
    "WorkflowRunCancelledWebhookEventParams",
    "WorkflowRunCompletedWebhookEventParams",
    "WorkflowRunFailedWebhookEventParams",
    "WorkflowRunNeedsReviewWebhookEventParams",
    "WorkflowRunParams",
    "WorkflowRunRejectedWebhookEventParams",
    "WorkflowRunStepRunProcessedWebhookEventParams",
    "WorkflowRunSummaryParams",
    "WorkflowStepBaseParams",
    "WorkflowSummaryParams",
    "WorkflowVersionParams",
    "WorkflowVersionSummaryParams",
]
