# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..core.serialization import FieldMetadata


class FileContentsSectionsItemParams(typing_extensions.TypedDict):
    start_page_number: typing_extensions.Annotated[int, FieldMetadata(alias="startPageNumber")]
    """
    The starting page number of this section.
    """

    end_page_number: typing_extensions.Annotated[int, FieldMetadata(alias="endPageNumber")]
    """
    The ending page number of this section.
    """

    markdown: str
    """
    The markdown content of this section.
    """
