# This file was auto-generated by Fern from our API Definition.

import typing

from .legacy_provided_classifier_output import LegacyProvidedClassifierOutput
from .legacy_provided_extraction_output import LegacyProvidedExtractionOutput
from .legacy_provided_splitter_output import LegacyProvidedSplitterOutput

LegacyProvidedProcessorOutput = typing.Union[
    LegacyProvidedExtractionOutput, LegacyProvidedClassifierOutput, LegacyProvidedSplitterOutput
]
