# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..core.serialization import FieldMetadata


class ParseConfigChunkingStrategyOptionsParams(typing_extensions.TypedDict):
    """
    Additional options for the chunking strategy.
    """

    min_characters: typing_extensions.NotRequired[
        typing_extensions.Annotated[int, FieldMetadata(alias="minCharacters")]
    ]
    """
    Specify a minimum number of characters per chunk.
    """

    max_characters: typing_extensions.NotRequired[
        typing_extensions.Annotated[int, FieldMetadata(alias="maxCharacters")]
    ]
    """
    Specify a maximum number of characters per chunk.
    """
