# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class FileFromTextParams(typing_extensions.TypedDict):
    """
    Raw text data to be processed. This will be used to create a `.txt` file.
    """

    text: str
    """
    A string containing raw text data to be processed.
    """

    name: typing_extensions.NotRequired[str]
    """
    The name of the created text file. If not set, the file name is generated.
    """
