# This file was auto-generated by Fern from our API Definition.

import typing

from .classify_result import ClassifyResultParams
from .classify_step_run_step import ClassifyStepRunStepParams
from .step_run_base import StepRunBaseParams


class ClassifyStepRunParams(StepRunBaseParams):
    step: ClassifyStepRunStepParams
    result: typing.Optional[ClassifyResultParams]
    """
    The result of this classify step. Currently, `result` is always present for returned step runs. It is nullable to allow for future support of returning step runs with non-successful statuses.
    """
