# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..core.serialization import FieldMetadata
from .edit_config_advanced_options import EditConfigAdvancedOptionsParams
from .edit_root_json import EditRootJsonParams


class EditConfigParams(typing_extensions.TypedDict):
    """
    Configuration options for the editing process.
    """

    schema: typing_extensions.NotRequired[EditRootJsonParams]
    instructions: typing_extensions.NotRequired[str]
    """
    Custom instructions provided for the edit operation.
    """

    advanced_options: typing_extensions.NotRequired[
        typing_extensions.Annotated[EditConfigAdvancedOptionsParams, FieldMetadata(alias="advancedOptions")]
    ]
    """
    Advanced options for the edit operation.
    """
