# This file was auto-generated by Fern from our API Definition.

import typing

from .extract_output_json import ExtractOutputJsonParams
from .extract_output_legacy import ExtractOutputLegacyParams

ExtractOutputParams = typing.Union[ExtractOutputJsonParams, ExtractOutputLegacyParams]
