# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ...core.serialization import FieldMetadata


class WorkflowRunsCreateBatchResponseParams(typing_extensions.TypedDict):
    batch_id: typing_extensions.Annotated[str, FieldMetadata(alias="batchId")]
    """
    A unique identifier for the submitted batch. This ID can be used to correlate the workflow runs created by this request. You can find this `batchId` associated with individual runs when listing workflow runs or in webhook payloads.
    """
