# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..core.serialization import FieldMetadata


class ParentSplitParams(typing_extensions.TypedDict):
    """
    The split metadata details for a derivative file.

    **Availability:** Only included if this file is a derivative of another file, for instance if it was created via a Splitter in a workflow.
    """

    id: str
    """
    The ID of the split.
    """

    type: str
    """
    The type of the split.
    """

    identifier: str
    """
    The identifier of the split.
    """

    start_page: typing_extensions.Annotated[int, FieldMetadata(alias="startPage")]
    """
    The start page of the split.
    """

    end_page: typing_extensions.Annotated[int, FieldMetadata(alias="endPage")]
    """
    The end page of the split.
    """
