# This file was auto-generated by Fern from our API Definition.

import typing

from ..types.legacy_extraction_field_result import LegacyExtractionFieldResult

LegacyFieldsArrayOutputParams = typing.Dict[str, LegacyExtractionFieldResult]
