# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ...core.serialization import FieldMetadata
from ...requests.provided_processor_output import ProvidedProcessorOutputParams


class EvaluationSetItemsCreateRequestItemsItemParams(typing_extensions.TypedDict):
    file_id: typing_extensions.Annotated[str, FieldMetadata(alias="fileId")]
    """
    Extend's internal ID for the file. It will always start with "file_".
    
    Example: `"file_xK9mLPqRtN3vS8wF5hB2cQ"`
    """

    expected_output: typing_extensions.Annotated[ProvidedProcessorOutputParams, FieldMetadata(alias="expectedOutput")]
    """
    The expected output that will be compared to the actual output of the extractor, classifier, or splitter when run against the file.
    """
