# This file was auto-generated by Fern from our API Definition.

import typing

from ..core import enum

T_Result = typing.TypeVar("T_Result")


class ParseConfigAdvancedOptionsExcelParsingMode(enum.StrEnum):
    """
    Controls how Excel files are parsed.

    * `basic`: Fast, deterministic parsing.
    * `advanced`: Enable layout block detection for complex spreadsheets.

    For `.xls` files, `basic` mode is always used.
    """

    BASIC = "basic"
    ADVANCED = "advanced"
    _UNKNOWN = "__PARSECONFIGADVANCEDOPTIONSEXCELPARSINGMODE_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "ParseConfigAdvancedOptionsExcelParsingMode":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        basic: typing.Callable[[], T_Result],
        advanced: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is ParseConfigAdvancedOptionsExcelParsingMode.BASIC:
            return basic()
        if self is ParseConfigAdvancedOptionsExcelParsingMode.ADVANCED:
            return advanced()
        return _unknown_member(self._value_)
