# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..core.serialization import FieldMetadata


class LegacyProvidedSplitterOutputSplitsItemParams(typing_extensions.TypedDict):
    id: str
    """
    Unique ID for this split
    """

    classification_id: typing_extensions.Annotated[str, FieldMetadata(alias="classificationId")]
    """
    ID of the classification type (set in the processor config)
    """

    type: str
    """
    The type of the split document (set in the processor config), corresponds to the classificationId
    """

    observation: typing_extensions.NotRequired[str]
    """
    Explanation of the results
    """

    identifier: typing_extensions.NotRequired[str]
    """
    Identifier for the split document (e.g. invoice number)
    """

    start_page: typing_extensions.Annotated[int, FieldMetadata(alias="startPage")]
    """
    The start page of the split document
    """

    end_page: typing_extensions.Annotated[int, FieldMetadata(alias="endPage")]
    """
    The end page of the split document
    """
